Learn R Programming

mizer (version 3.0.0)

.checkRateFunctionOutput: Check that a rate function returns the correct output dimensions

Description

Called by setRateFunction() to verify that a candidate rate function returns an array (or vector/list) of the correct dimensions for the requested rate.

Usage

.checkRateFunctionOutput(params, rate, fun)

Value

Invisibly NULL. Called for its side-effect of stopping with an informative error if the output has the wrong shape.

Arguments

params

A MizerParams object

rate

Name of the rate being replaced, e.g. "Encounter".

fun

Name of the candidate function to validate.