NOther: Time series of other components

View source: R/extension.R

NOtherR Documentation

Time series of other components

Description

Fetch the simulation results for other components over time.

Usage

NOther(sim)

finalNOther(sim)

Arguments

sim

A MizerSim object

Value

For NOther: A list array indexed by time and component that stores the projected values for other ecosystem components.

For finalNOther: A named list holding the values of other ecosystem components at the end of the simulation

See Also

Other extension tools: coerceToExtensionClass(), initialNOther<-(), other_mort(), recordExtension(), setComponent(), setRateFunction()


mizer documentation built on Aug. 31, 2026, 5:08 p.m.