age_mat: Calculate age at maturity

View source: R/age_mat.R

age_matR Documentation

Calculate age at maturity

Description

Uses the size-dependent growth rate and the size at maturity to calculate the age at maturity.

Usage

age_mat(params, ...)

Arguments

params

A MizerParams object

...

Currently unused.

Details

Using that by definition of the growth rate g(w) = dw/dt we have that

\mathrm{age_{mat}} = \int_0^{w_{mat}.}\frac{dw}{g(w)}

In the implementation this integral is approximated on the model size grid by summing dw / g(w) over all size bins with w < w_mat.

Value

A named vector. The names are the species names and the values are the ages at maturity.

Examples

age_mat(NS_params)

mizer documentation built on Aug. 31, 2026, 5:08 p.m.