as_series_matrix: Bring what a value function returned into a time by series...

View source: R/scanModel.R

as_series_matrixR Documentation

Bring what a value function returned into a time by series matrix

Description

Bring what a value function returned into a time by series matrix

Usage

as_series_matrix(x, default_name = "Value")

Arguments

x

The return value of a value_func.

default_name

The column name to use for a single unnamed series.

Value

A matrix with time in the rows and the series in the columns.


mizer documentation built on Aug. 24, 2026, 9:08 a.m.