check_band_vars: Check that a data frame has the variables a band style needs

View source: R/plots.R

check_band_varsR Documentation

Check that a data frame has the variables a band style needs

Description

Check that a data frame has the variables a band style needs

Usage

check_band_vars(var_names, style)

Arguments

var_names

The names of the variables in the data frame.

style

The style that was requested.

Value

Nothing; called for the error.


mizer documentation built on Aug. 24, 2026, 9:08 a.m.