check_per_log_size: Check that 'per_log_size' applies to a mizer array

View source: R/ArraySpeciesBySize-class.R

check_per_log_sizeR Documentation

Check that per_log_size applies to a mizer array

Description

Expressing values per logarithmic size only means anything for a density, so asking for it on anything else is an argument error rather than something to be quietly ignored — which is what ... used to do with it.

Usage

check_per_log_size(x, per_log_size)

Arguments

x

A mizer array object.

per_log_size

The per_log_size argument of the plot method.

Value

per_log_size, invisibly, if it applies.


mizer documentation built on Aug. 24, 2026, 9:08 a.m.