View source: R/registerExtensions.R
| coerceToExtensionClass | R Documentation |
Coerces a MizerParams or MizerSim object to the S3 class hierarchy
corresponding to the object's own extension list. For MizerSim, the
extension names are read from the embedded MizerParams object.
coerceToExtensionClass(object, extensions = objectExtensions(object))
object |
A |
extensions |
Optional extension list or vector. Defaults to the extensions stored in
|
This is infrastructure for extension package authors. Ordinary users should
load saved models with readParams() or readSim(); validParams() and
validSim() repair the class vector of an object that is already in memory.
The same object coerced to the appropriate S3 class vector, or to the base class for an empty extension list.
"Creating a mizer extension package": Creating a mizer extension package
Other extension tools:
NOther(),
initialNOther<-(),
other_mort(),
recordExtension(),
setComponent(),
setRateFunction()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.