collect_dimnames: Assemble the dimnames of a broadcast array

View source: R/sizeIntegral.R

collect_dimnamesR Documentation

Assemble the dimnames of a broadcast array

Description

Internal helper for sizeIntegral() that takes the dimnames of each labelled dimension from the first of the given arrays that has them.

Usage

collect_dimnames(target_labels, arrays, labels)

Arguments

target_labels

The dimension labels of the result.

arrays

A list of arrays.

labels

A list of the corresponding label vectors.

Value

A named list of dimnames, or NULL if none of the arrays has any.


mizer documentation built on Aug. 24, 2026, 9:08 a.m.