View source: R/compareParams.R
| compareParams | R Documentation |
Compare two MizerParams objects and print out differences
compareParams(params1, params2, ...)
params1 |
First MizerParams object |
params2 |
Second MizerParams object |
... |
Additional arguments passed to the method. |
Invisibly returns a character vector of difference messages, one element per difference. As a side effect, prints the differences in a human-readable format.
params1 <- NS_params
params2 <- params1
species_params(params2)$w_mat[1] <- 10
# Keep this example focused on the model parameter.
params2@time_modified <- params1@time_modified
compareParams(params1, params2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.