Sets defaults for missing but required species parameters.
completeSpeciesParams(species_params)A completed species parameter data frame
The function sets default values if any of the following species parameters are missing or NA:
w_mat is set to w_max/4
w_min is set to 0.001
alpha is set to 0.6
interaction_resource is set to 1
n is set to 3/4
It calls validSpeciesParams() to check the validity of the species
parameters. Nevertheless the species parameters returned by this function are not guaranteed
to produce a viable model. More checks of the parameters are performed by the
individual rate-setting functions (see setParams() for the list of these
functions).
The user-supplied species parameter data frame
species_params(), validSpeciesParams()