| convert_plot_size_axis | R Documentation |
When size_axis = "l", adds a length column l computed from the weight
column w using the weight-length relationship of each line, see
plot_length_params(). Rows with no such relationship are dropped. For
size_axis = "w" the data is returned unchanged.
convert_plot_size_axis(
plot_dat,
params,
size_axis,
species_col = "Species",
drop_w = TRUE
)
plot_dat |
A data frame of plotting data with a |
params |
A MizerParams object providing the weight-length parameters. |
size_axis |
Either |
species_col |
Name of the column identifying the species. Default is
|
drop_w |
If |
The plotting data, with a length column l added (and w optionally
dropped) when size_axis = "l".
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.