View source: R/registerExtensions.R
| defineOrCheckClass | R Documentation |
If class does not yet exist, defines it as a virtual-free S4 class that
contains parent, registered in .GlobalEnv. If class already exists,
stops with an error unless it already extends parent.
defineOrCheckClass(class, parent)
class |
Character string — the S4 class name to define or check. |
parent |
Character string — the required parent class. |
Invisibly, class.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.