density_measure_jacobian: Jacobian converting between two density measures

View source: R/plots.R

density_measure_jacobianR Documentation

Jacobian converting between two density measures

Description

Jacobian converting between two density measures

Usage

density_measure_jacobian(from, to, w, l, b)

Arguments

from, to

Density measures, see density_measures.

w, l, b

Numeric vectors of the same length giving the weight, the corresponding length, and the exponent of the weight-length relationship.

Value

A numeric vector by which to multiply a density with respect to from to obtain the density with respect to to.


mizer documentation built on Aug. 31, 2026, 5:08 p.m.