density_size_unit: The size unit appearing in the units of a density

View source: R/plots.R

density_size_unitR Documentation

The size unit appearing in the units of a density

Description

The size unit appearing in the units of a density

Usage

density_size_unit(measure)

Arguments

measure

One of density_measures.

Value

"g" or "cm", or NA_character_ for a density with respect to a logarithmic size, whose units carry no size unit.


mizer documentation built on Aug. 31, 2026, 5:08 p.m.