dim_extents: Collect the extent of each labelled dimension

View source: R/sizeIntegral.R

dim_extentsR Documentation

Collect the extent of each labelled dimension

Description

Internal helper for sizeIntegral() that checks that arrays sharing a dimension label agree on its extent.

Usage

dim_extents(arrays, labels)

Arguments

arrays

A list of arrays.

labels

A list of the corresponding label vectors.

Value

A named integer vector giving the extent of each label.


mizer documentation built on Aug. 24, 2026, 9:08 a.m.