dim_from_labels: The dimensions of an array, given its labels

View source: R/sizeIntegral.R

dim_from_labelsR Documentation

The dimensions of an array, given its labels

Description

Internal helper for sizeIntegral(). A scalar has no labels and no dimensions, a vector has one.

Usage

dim_from_labels(x, labels)

Arguments

x

An array, vector or scalar.

labels

Its dimension labels.

Value

An integer vector of dimensions, of the same length as labels.


mizer documentation built on Aug. 24, 2026, 9:08 a.m.