| extension_needs_upgrading | R Documentation |
Returns TRUE if, for any extension recorded on the object whose package is
installed, the recorded version stamp is missing (NA)
or older than the installed version of that package. A missing stamp counts
as needing an upgrade so that objects created before extension-version
tracking are brought up to date (and stamped) on first use; this is safe
because runExtensionUpgrades() only calls an upgrade method if one is registered and
such methods are written to be idempotent.
extension_needs_upgrading(params)
params |
A MizerParams object. |
TRUE or FALSE.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.