filter_plot_length_limits: Filter plotting data to the requested length limits

View source: R/plots.R

filter_plot_length_limitsR Documentation

Filter plotting data to the requested length limits

Description

Filter plotting data to the requested length limits

Usage

filter_plot_length_limits(plot_dat, llim)

Arguments

plot_dat

A data frame of plotting data, possibly with an l (length) column.

llim

Numeric vector of length two giving the lower and upper length limits. Use NA to apply no limit at that end.

Value

plot_dat filtered to the length limits, or unchanged if it has no l column.


mizer documentation built on Aug. 24, 2026, 9:08 a.m.