Learn R Programming

mizer (version 3.0.0)

finalParams: Extract the final state from a simulation

Description

Returns the MizerParams object underlying the simulation with its initial abundances set to the abundances at the last saved time step of the simulation. This is a convenience wrapper around getParams() with no time_range argument (the default).

Usage

finalParams(sim)

Value

A MizerParams object with initial values taken from the final time step of the simulation.

Arguments

sim

A MizerSim object.

See Also

getParams(), initialParams()

Examples

Run this code
sim <- project(NS_params, t_max = 20, effort = 0.5)
params_end <- finalParams(sim)

Run the code above in your browser using DataLab