flux_units: Units string for the flux returned by 'getFlux()'

View source: R/rate_functions.R

flux_unitsR Documentation

Units string for the flux returned by getFlux()

Description

Units string for the flux returned by getFlux()

Usage

flux_units(power)

Arguments

power

The power of weight the flux was multiplied by.

Value

A character string with the units of the flux.


mizer documentation built on Aug. 31, 2026, 5:08 p.m.