free_gear_name: A gear name that the model is not already using

View source: R/scan_setters.R

free_gear_nameR Documentation

A gear name that the model is not already using

Description

A gear name that the model is not already using

Usage

free_gear_name(params)

Arguments

params

A MizerParams object.

Value

A string naming a gear that does not exist in params.


mizer documentation built on Aug. 31, 2026, 5:08 p.m.