View source: R/rate_functions.R
| getEGrowth | R Documentation |
Calculates the energy rate g_i(w) (grams/year) available by species and
size for growth after metabolism, movement and reproduction have been
accounted for.
getEGrowth(object, ...)
object |
A MizerParams or MizerSim object. |
... |
Additional arguments that depend on the class of For a MizerParams object:
For a MizerSim object:
|
The growth rate is calculated as the difference between the energy available
for reproduction and growth (obtainable with getEReproAndGrowth()) and
the energy used for reproduction (obtainable with getERepro()), but is
set to 0 if the result would be negative.
MizerParams: An ArraySpeciesBySize object (species x size) with the
somatic growth rates (grams/year).
MizerSim: An ArrayTimeBySpeciesBySize object (time step x species x
size) with the growth rates at every time step. If drop = TRUE then
dimensions of length 1 will be removed.
By default getEGrowth() calls mizerEGrowth(). However you can
replace this with your own alternative growth rate function. If
your function is called "myEGrowth" then you register it in a MizerParams
object params with
params <- setRateFunction(params, "EGrowth", "myEGrowth")
Your function will then be called instead of mizerEGrowth(), with the
same arguments.
getERepro(), getEReproAndGrowth()
Other rate functions:
getDiffusion(),
getERepro(),
getEReproAndGrowth(),
getEncounter(),
getFMort(),
getFMortGear(),
getFeedingLevel(),
getFlux(),
getFluxGradient(),
getMort(),
getPredMort(),
getPredRate(),
getRDD(),
getRDI(),
getRates(),
getResourceMort()
params <- NS_params
# Project with constant fishing effort for all gears for 20 time steps
sim <- project(params, t_max = 20, effort = 0.5)
# Get the energy at a particular time step
growth <- getEGrowth(params, n = N(sim)[15, , ], n_pp = NResource(sim)[15, ], t = 15)
# Growth rate at this time for Sprat of size 2g
growth["Sprat", "2"]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.