View source: R/rate_functions.R
| getEReproAndGrowth | R Documentation |
Calculates the energy rate E_{r.i}(w) (grams/year) available for
reproduction and growth after metabolism and movement have been accounted
for.
getEReproAndGrowth(object, ...)
object |
A MizerParams or MizerSim object. |
... |
Additional arguments that depend on the class of For a MizerParams object:
For a MizerSim object:
|
MizerParams: An ArraySpeciesBySize object (species x size) with the
energy rate E_{r.i}(w) available for growth and reproduction
(grams/year).
MizerSim: An ArrayTimeBySpeciesBySize object (time step x species x
size) with the energy rate at every time step. If drop = TRUE then
dimensions of length 1 will be removed.
By default getEReproAndGrowth() calls mizerEReproAndGrowth(). However you
can replace this with your own alternative energy rate function. If
your function is called "myEReproAndGrowth" then you register it in a
MizerParams object params with
params <- setRateFunction(params, "EReproAndGrowth", "myEReproAndGrowth")
Your function will then be called instead of mizerEReproAndGrowth(), with
the same arguments.
The part of this energy rate that is invested into growth is
calculated with getEGrowth() and the part that is invested into
reproduction is calculated with getERepro().
Other rate functions:
getDiffusion(),
getEGrowth(),
getERepro(),
getEncounter(),
getFMort(),
getFMortGear(),
getFeedingLevel(),
getFlux(),
getFluxGradient(),
getMort(),
getPredMort(),
getPredRate(),
getRDD(),
getRDI(),
getRates(),
getResourceMort()
params <- NS_params
# Project with constant fishing effort for all gears for 20 time steps
sim <- project(params, t_max = 20, effort = 0.5)
# Get the energy at a particular time step
e <- getEReproAndGrowth(params, n = N(sim)[15, , ],
n_pp = NResource(sim)[15, ], t = 15)
# Rate at this time for Sprat of size 2g
e["Sprat", "2"]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.