View source: R/rate_functions.R
| getFMort | R Documentation |
Calculates the total fishing mortality (in units 1/year) from all gears by
species and size and possibly time. See setFishing() for details of
how fishing gears are set up.
getFMort(object, ...)
object |
A MizerParams or MizerSim object. |
... |
Additional arguments that depend on the class of For a MizerParams object:
For a MizerSim object:
|
The total fishing mortality is just the sum of the fishing mortalities
imposed by each gear, F_i(w)=\sum_g F_{g,i,w}.
The fishing mortality for each gear is obtained as catchability x
selectivity x effort.
MizerParams with vector effort: An ArraySpeciesBySize object
(species x size) with the fishing mortality rates.
MizerParams with time-dimensioned effort or MizerSim: An
ArrayTimeBySpeciesBySize object (time x species x size).
The effort argument is only used if a MizerParams object is
passed in. The effort argument can be a two dimensional array (time x
gear), a vector of length equal to the number of gears (each gear has a
different effort that is constant in time), or a single numeric value (each
gear has the same effort that is constant in time). The order of gears in the
effort argument must be the same as in the MizerParams
object.
If the object argument is of class MizerSim then the effort slot of
the MizerSim object is used and the effort argument is not
used.
By default getFMort() calls mizerFMort(). However you can
replace this with your own alternative fishing mortality function. If
your function is called "myFMort" then you register it in a MizerParams
object params with
params <- setRateFunction(params, "FMort", "myFMort")
Your function will then be called instead of mizerFMort(), with the
same arguments.
Other rate functions:
getDiffusion(),
getEGrowth(),
getERepro(),
getEReproAndGrowth(),
getEncounter(),
getFMortGear(),
getFeedingLevel(),
getFlux(),
getFluxGradient(),
getMort(),
getPredMort(),
getPredRate(),
getRDD(),
getRDI(),
getRates(),
getResourceMort()
params <- NS_params
# Get the total fishing mortality in the initial state
F <- getFMort(params, effort = 1)
str(F)
# Get the initial total fishing mortality when effort is different
# between the four gears:
F <- getFMort(params, effort = c(0.5,1,1.5,0.75))
# Get the total fishing mortality when effort is different
# between the four gears and changes with time:
effort <- array(NA, dim = c(20,4))
effort[, 1] <- seq(from = 0, to = 1, length = 20)
effort[, 2] <- seq(from = 1, to = 0.5, length = 20)
effort[, 3] <- seq(from = 1, to = 2, length = 20)
effort[, 4] <- seq(from = 2, to = 1, length = 20)
F <- getFMort(params, effort = effort)
str(F)
# Get the total fishing mortality using the effort already held in a
# MizerSim object.
sim <- project(params, t_max = 20, effort = 0.5)
F <- getFMort(sim)
F <- getFMort(sim, time_range = c(10, 20))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.