| getPhiPrey | R Documentation |
This is deprecated and is no longer used by the mizer project() method.
Calculates the amount E_{a,i}(w) of food exposed to each predator as
a function of predator size.
getPhiPrey(object, n, n_pp, ...)
object |
An MizerParams object |
n |
A matrix of species abundances (species x size) |
n_pp |
A vector of the background abundance by size |
... |
Other arguments (currently unused) |
A two dimensional array (predator species x predator size)
equal to getEncounter(object, n, n_pp) / search_vol(object).
project()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.