View source: R/indicator_functions.R
| getProportionOfLargeFish | R Documentation |
Calculates the proportion of large fish in a MizerSim or MizerParams
object within user defined size limits. The default option is to use the
whole size range. You can specify minimum and maximum size ranges for the
species and also the threshold size for large fish. Sizes can be expressed
as weight or length. Lengths take precedence over weights (i.e. if both
min_l and min_w are supplied, only min_l will be used, and if
threshold_l is supplied it takes precedence over threshold_w). You can
also specify the species to be used in the calculation. This function can be
used to calculate the Large Fish Index. The proportion is based on either
abundance or biomass.
getProportionOfLargeFish(
object,
species = NULL,
threshold_w = 100,
threshold_l = NULL,
biomass_proportion = TRUE,
...
)
object |
A MizerSim or MizerParams object |
species |
The species to be selected. Optional. By default all target species are selected. A vector of species names, or a numeric vector with the species indices, or a logical vector indicating for each species whether it is to be selected (TRUE) or not. |
threshold_w |
The weight used as the cutoff between large and small fish. Default value is 100. |
threshold_l |
The length used as the cutoff between large and small
fish. If supplied, this takes precedence over |
biomass_proportion |
A boolean value. If TRUE the proportion calculated is based on biomass, if FALSE it is based on numbers of individuals. Default is TRUE. |
... |
Arguments passed on to
|
A vector containing the proportion of large fish through time, or a
single value if called with a MizerParams object.
Other functions for calculating indicators:
getCommunitySlope(),
getMeanMaxWeight(),
getMeanWeight()
lfi <- getProportionOfLargeFish(NS_sim, min_w = 10, max_w = 5000,
threshold_w = 500)
years <- c("1972", "2010")
lfi[years]
getProportionOfLargeFish(NS_sim)[years]
getProportionOfLargeFish(NS_sim, species=c("Herring","Sprat","N.pout"))[years]
getProportionOfLargeFish(NS_sim, min_w = 10, max_w = 5000)[years]
getProportionOfLargeFish(NS_sim, min_w = 10, max_w = 5000,
threshold_w = 500, biomass_proportion = FALSE)[years]
getProportionOfLargeFish(NS_params)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.