View source: R/rate_functions.R
| getRDD | R Documentation |
Calculates the density dependent rate of egg production R_i (units
1/year) for each species. This is the flux entering the smallest size class
of each species. The density dependent rate is the density independent
rate obtained with getRDI() after it has been put through the
density dependence function. This is the Beverton-Holt function
BevertonHoltRDD() by default, but this can be changed. See
setReproduction() for more details.
getRDD(object, ...)
object |
A MizerParams or MizerSim object. |
... |
Additional arguments that depend on the class of For a MizerParams object:
For a MizerSim object:
|
MizerParams: A numeric vector the length of the number of species.
MizerSim: An ArrayTimeBySpecies object (time x species).
getRDI()
Other rate functions:
getDiffusion(),
getEGrowth(),
getERepro(),
getEReproAndGrowth(),
getEncounter(),
getFMort(),
getFMortGear(),
getFeedingLevel(),
getFlux(),
getFluxGradient(),
getMort(),
getPredMort(),
getPredRate(),
getRDI(),
getRates(),
getResourceMort()
params <- NS_params
# Project with constant fishing effort for all gears for 20 time steps
sim <- project(params, t_max = 20, effort = 0.5)
# Get the rate at a particular time step
getRDD(params, n = N(sim)[15, , ], n_pp = NResource(sim)[15, ], t = 15)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.