getRDI: Get density independent rate of egg production

View source: R/rate_functions.R

getRDIR Documentation

Get density independent rate of egg production

Description

Calculates the density-independent rate of total egg production R_{di} (units 1/year) before density dependence, by species.

Usage

getRDI(object, ...)

Arguments

object

A MizerParams or MizerSim object.

...

Additional arguments that depend on the class of object.

For a MizerParams object:

n

A matrix of species abundances (species x size). Defaults to the initial abundances stored in object.

n_pp

A vector of the resource abundance by size. Defaults to the initial resource abundance stored in object.

n_other

A named list of the abundances of other dynamical components. Defaults to the initial values stored in object.

t

The time for which to do the calculation. Defaults to 0.

For a MizerSim object:

time_range

The time range over which to return the rates. Either a vector of values, a vector of min and max time, or a single value. Defaults to the whole time range of the simulation.

Details

This rate is obtained by taking the per capita rate E_r(w)\psi(w) at which energy is invested in reproduction, as calculated by getERepro(), multiplying it by the number of individualsN(w) and integrating over all sizes w and then multiplying by the reproductive efficiency \epsilon and dividing by the egg size w_min, and by a factor of two to account for the two sexes:

R_{di} = \frac{\epsilon}{2 w_{min}} \int N(w) E_r(w) \psi(w) \, dw

Used by getRDD() to calculate the actual, density dependent rate. See setReproduction() for more details.

Value

  • MizerParams: A numeric vector the length of the number of species.

  • MizerSim: An ArrayTimeBySpecies object (time x species).

Your own reproduction function

By default getRDI() calls mizerRDI(). However you can replace this with your own alternative reproduction function. If your function is called "myRDI" then you register it in a MizerParams object params with

params <- setRateFunction(params, "RDI", "myRDI")

Your function will then be called instead of mizerRDI(), with the same arguments. For an example of an alternative reproduction function see constantEggRDI().

See Also

getRDD()

Other rate functions: getDiffusion(), getEGrowth(), getERepro(), getEReproAndGrowth(), getEncounter(), getFMort(), getFMortGear(), getFeedingLevel(), getFlux(), getFluxGradient(), getMort(), getPredMort(), getPredRate(), getRDD(), getRates(), getResourceMort()

Examples


params <- NS_params
# Project with constant fishing effort for all gears for 20 time steps
sim <- project(params, t_max = 20, effort = 0.5)
# Get the density-independent reproduction rate at a particular time step
getRDI(params, n = N(sim)[15, , ], n_pp = NResource(sim)[15, ], t = 15)


mizer documentation built on Aug. 31, 2026, 5:08 p.m.