View source: R/summary_methods.R
| getSSB | R Documentation |
Calculates the spawning stock biomass (SSB) for each species. For a
MizerSim object this is returned for every saved time; for a
MizerParams object it is calculated from the initial state. SSB is the
total mass of all mature individuals.
getSSB(object)
object |
An object of class |
If called with a MizerParams object, a named vector with the SSB in
grams for each species in the model. If called with a MizerSim object, a
ArrayTimeBySpecies object (time x species) containing the SSB in grams
at each time step for all species.
Other summary functions:
getBiomass(),
getDiet(),
getGrowthCurves(),
getN(),
getSteadyResidual(),
getTrophicLevel(),
getTrophicLevelBySpecies(),
getYield(),
getYieldGear()
ssb <- getSSB(NS_sim)
ssb[c("1972", "2010"), c("Herring", "Cod")]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.