getSimParams: Extract the projection parameters used to produce a...

View source: R/MizerSim-class.R

getSimParamsR Documentation

Extract the projection parameters used to produce a simulation

Description

Returns the named list of arguments passed to project() or projectUntilSettled() when producing this MizerSim object, such as method and dt. Returns an empty list for simulations produced by older versions of mizer.

Usage

getSimParams(sim)

Arguments

sim

A MizerSim object

Value

A named list of projection parameters.

Examples

sim <- project(NS_params, t_max = 0.1, dt = 0.05, method = "predictor-corrector")
getSimParams(sim)

mizer documentation built on Aug. 31, 2026, 5:08 p.m.