View source: R/summary_methods.R
| getTrophicLevelBySpecies | R Documentation |
Calculates the consumption-rate-weighted mean trophic level of each species,
defined as
T_i = \frac{\int r_i(w)\,N_i(w)\,T_i(w)\,dw}
{\int r_i(w)\,N_i(w)\,dw},
where r_i(w) = (1 - f_i(w))\,E_i(w) is the consumption rate of an
individual of species i at weight w, N_i(w) is the
abundance density, and T_i(w) is the size-resolved trophic level
from getTrophicLevel(). As in getTrophicLevel(), the resource is given a
size-dependent trophic level controlled by the w_R and beta_R arguments.
getTrophicLevelBySpecies(
params,
n = initialN(params),
n_pp = initialNResource(params),
n_other = initialNOther(params),
w_R = 1e-10,
beta_R = 1000,
...
)
params |
A MizerParams object. |
n |
A matrix of species abundances (species x size). Defaults to
the initial abundances stored in |
n_pp |
A vector of the resource abundance by size. Defaults to the
initial resource abundance stored in |
n_other |
A named list of the abundances of other dynamical
components. Defaults to the initial values stored in |
w_R |
An average size (in grams) of primary producers in the resource
spectrum, used to set the size-dependent resource trophic level. Defaults
to |
beta_R |
An average predator/prey mass ratio for the resource spectrum,
used to set the size-dependent resource trophic level. Must be greater than
|
... |
Unused |
A named vector with the mean trophic level for each species.
getTrophicLevel()
Other summary functions:
getBiomass(),
getDiet(),
getGrowthCurves(),
getN(),
getSSB(),
getSteadyResidual(),
getTrophicLevel(),
getYield(),
getYieldGear()
getTrophicLevelBySpecies(NS_params)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.