View source: R/summary_methods.R
| getYieldGear | R Documentation |
This yield rate is given in grams per year. It is calculated at each time step saved in the MizerSim object.
getYieldGear(object)
object |
An object of class |
For details of how the yield rate is defined see the help page of
getYield().
If called with a MizerParams object, an array (gear x species) with the yield rate in grams per year from each gear for each species in the model. If called with a MizerSim object, an array (time x gear x species) containing the yield rate at each time step.
getYield()
Other summary functions:
getBiomass(),
getDiet(),
getGrowthCurves(),
getN(),
getSSB(),
getSteadyResidual(),
getTrophicLevel(),
getTrophicLevelBySpecies(),
getYield()
yield <- getYieldGear(NS_sim)
dim(yield)
yield["1972", , "Herring"]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.