get_ArrayResourceBySize_w: Get the size grid for an ArrayResourceBySize object

View source: R/ArrayResourceBySize-class.R

get_ArrayResourceBySize_wR Documentation

Get the size grid for an ArrayResourceBySize object

Description

Internal helper that returns the full prey/resource size grid params@w_full, or the numeric vector parsed from the names of x if no params is attached.

Usage

get_ArrayResourceBySize_w(x)

Arguments

x

An ArrayResourceBySize object.

Value

A numeric vector giving the size represented by each element.


mizer documentation built on Aug. 24, 2026, 9:08 a.m.