| get_gamma_default | R Documentation |
Fills in any missing values for gamma so that fish feeding on a resource
spectrum described by the power law \kappa w^{-\lambda} achieve a
feeding level f_0. Only for internal use.
get_gamma_default(params)
params |
A MizerParams object |
See the Search Volume Coefficient section of the "Calculation of Default Parameter Values" vignette for the mathematical derivation.
The available energy is measured with the predation part of mizer's own
encounter rate, mizerEncounter(). It is a property of the species
parameters and of the resource power law rather than of the model's dynamics,
so external encounter and contributions registered with other_encounter()
(including component encounter functions) are excluded. The measurement also
deliberately does not go through the extension dispatch chain, nor through an
encounter function registered with setRateFunction().
A vector with the values of gamma for all species
Other functions calculating defaults:
get_f0_default(),
get_h_default(),
get_ks_default()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.