| get_ks_default | R Documentation |
ksFills in any missing values for ks so that the critical feeding level needed
to sustain the species is as specified in the fc column in the species
parameter data frame. If that column is not provided the default critical
feeding level f_c = 0.2 is used.
get_ks_default(params)
params |
A MizerParams object |
See the Standard Metabolic Rate Coefficient section of the "Calculation of Default Parameter Values" vignette for the mathematical derivation.
A vector with the values of ks for all species
Other functions calculating defaults:
get_f0_default(),
get_gamma_default(),
get_h_default()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.