This function calculates the steady state abundance by solving the transport equation with given growth and mortality rates. It sets up a tri-diagonal system and solves it.
get_steady_state_n(params, g, mu, D, N0)A matrix with the steady state abundance
A MizerParams object
A matrix of growth rates (species x size)
A matrix of mortality rates (species x size)
A matrix of diffusion rates (species x size)
A vector with the abundance at the smallest size for each species