| get_time_elements | R Documentation |
Internal helper to select the saved time points whose times lie between the
smallest and largest values in time_range, inclusive.
get_time_elements(sim, time_range, slot_name = "n")
sim |
A MizerSim object. |
time_range |
A numeric or character vector of times. Only the range of
values matters, so all saved times between |
slot_name |
Obsolete, kept only for backward compatibility with early versions where different time-based slots could have different time grids. Leave at the default. |
A named logical vector, with one entry for each saved time in sim,
indicating whether that time lies in the requested range.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.