initialNOther-set: Initial values for other ecosystem components

initialNOther<-R Documentation

Initial values for other ecosystem components

Description

Values used as starting values for simulations with project().

Usage

initialNOther(params) <- value

initialNOther(object)

Arguments

params

A MizerParams object

value

A named list with the initial values of other ecosystem components

object

An object of class MizerParams or MizerSim

Value

A named list with the initial values of other ecosystem components

See Also

initialNResource(), initialN()

Other extension tools: NOther(), coerceToExtensionClass(), other_mort(), recordExtension(), setComponent(), setRateFunction()


mizer documentation built on Aug. 31, 2026, 5:08 p.m.