Learn R Programming

mizer (version 3.0.0)

initialParams: Extract the initial state from a simulation

Description

Returns the MizerParams object underlying the simulation with its initial abundances set to the abundances at the initial time of the simulation.

Usage

initialParams(sim)

Value

A MizerParams object with initial state of the simulation.

Arguments

sim

A MizerSim object.

See Also

getParams(), finalParams()

Examples

Run this code
sim <- project(NS_params, t_max = 20, effort = 0.5)
params_start <- initialParams(sim)

Run the code above in your browser using DataLab