isSuffixChain: Test whether one extension chain is a suffix of another

View source: R/registerExtensions.R

isSuffixChainR Documentation

Test whether one extension chain is a suffix of another

Description

An empty candidate is always a suffix. Order and values must match exactly for the overlapping tail.

Usage

isSuffixChain(candidate, chain)

Arguments

candidate

Named character vector to test.

chain

Named character vector that may contain candidate as a tail.

Value

TRUE if candidate is a suffix of chain, FALSE otherwise.


mizer documentation built on Aug. 24, 2026, 9:08 a.m.