View source: R/selectivity_funcs.R
| knife_edge | R Documentation |
A knife-edge selectivity function where weights greater or equal to
knife_edge_size are fully selected and no fish smaller than this size
are selected.
knife_edge(w, knife_edge_size, ...)
w |
Vector of sizes. |
knife_edge_size |
The weight at which the knife-edge operates. |
... |
Unused |
You would not usually call this function directly. Instead, set the sel_func
column in gear_params() to "knife_edge" and provide knife_edge_size as
an additional column. setFishing() will then call this function
automatically when calculating the selectivity array.
Vector of selectivities at the given sizes.
gear_params() for setting the knife_edge_size parameter.
Other selectivity functions:
double_sigmoid_length(),
knife_edge_length(),
sigmoid_length(),
sigmoid_weight()
knife_edge(w = c(1, 10, 100, 1000), knife_edge_size = 100)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.