length_at_size: Length of an individual at each weight on the size grid

View source: R/indicator_functions.R

length_at_sizeR Documentation

Length of an individual at each weight on the size grid

Description

Internal helper for getMeanLength(). Inverts the length-weight relationship w = a_i l^{b_i} of each species at every weight in params@w. The result is a weighting factor for sizeIntegral(), so it is a point value on the grid and is not bin-averaged here.

Usage

length_at_size(params)

Arguments

params

A MizerParams object.

Value

A species x size matrix of lengths in cm.


mizer documentation built on Aug. 31, 2026, 5:08 p.m.