make_linesize: Construct a named vector of line widths for a plot

View source: R/plots.R

make_linesizeR Documentation

Construct a named vector of line widths for a plot

Description

Helper used by the plotting functions to give highlighted species a thicker line than the rest.

Usage

make_linesize(levels, highlight)

Arguments

levels

Character vector of the legend levels (usually species names).

highlight

Name or vector of names of the levels to be highlighted with a thicker line.

Value

A named numeric vector of line widths, one for each entry in levels, with highlighted entries set to a larger value.


mizer documentation built on Aug. 31, 2026, 5:08 p.m.