make_mizer_plot: Tag a ggplot object as a mizer plot

View source: R/plots.R

make_mizer_plotR Documentation

Tag a ggplot object as a mizer plot

Description

Attaches the tooltip information to a ggplot object and adds the "mizer_plot" class so that plotHover() knows which aesthetics to show.

Usage

make_mizer_plot(plot, tooltip)

Arguments

plot

A ggplot object.

tooltip

Character vector of variable names to include in the plotly tooltip.

Value

The plot object with the tooltip stored as an attribute and "mizer_plot" prepended to its class.


mizer documentation built on Aug. 24, 2026, 9:08 a.m.