Learn R Programming

mizer (version 3.4.0)

match_to: Match a quantity to observations species by species

Description

Internal implementation shared by matchBiomasses() and matchNumbers(). Multiplies the abundance density of each selected species at all sizes by the factor that brings the modelled quantity onto the observation. Species that were not selected, or that have no positive observation, are left alone.

Usage

match_to(params, species = NULL, to = c("biomass", "number"), fname)

Value

A MizerParams object.

Arguments

params

A MizerParams object.

species

The species to be affected, in any of the forms accepted by valid_species_arg().

to

The type of observation, either "biomass" or "number".

fname

The name of the calling function, used when reporting that the model has been moved off its steady state.