mizer_needs_upgrading: Whether the core mizer slots of an object need upgrading

View source: R/upgrade.R

mizer_needs_upgradingR Documentation

Whether the core mizer slots of an object need upgrading

Description

Whether the core mizer slots of an object need upgrading

Usage

mizer_needs_upgrading(params)

Arguments

params

A MizerParams object.

Value

TRUE or FALSE.


mizer documentation built on Aug. 31, 2026, 5:08 p.m.