View source: R/wrapper_functions.R
| newCommunityParams | R Documentation |
This functions creates a MizerParams object describing a
community-type model.
The function has many arguments, all of which have default values.
newCommunityParams(
max_w = 1e+06,
min_w = 0.001,
no_w = 100,
min_w_pp = 1e-10,
z0 = 0.1,
alpha = 0.2,
f0 = 0.7,
h = 10,
gamma = NA,
beta = 100,
sigma = 2,
n = 2/3,
kappa = 1000,
lambda = 2.05,
r_pp = 10,
knife_edge_size = 1000,
reproduction,
second_order_w = FALSE,
info_level = default_info_level(2)
)
A community model has several features that distinguish it from a multi-species model:
Species identities of individuals are ignored. All are aggregated into a single community.
The resource spectrum only extends to the start of the community spectrum.
Reproductive rate is constant, independent of the energy invested in reproduction, which is set to 0.
Standard metabolism is turned off (the parameter ks is set to 0).
Consequently, the growth rate is now determined solely by the assimilated
food
Fishing selectivity is modelled as a knife-edge function with one parameter,
knife_edge_size, which determines the size at which species are
selected.
Because this constructor does not yet set up stochastic growth by diffusion,
the size grid is not extended beyond the community's maximum size max_w
(so that w_max = w_repro_max), rather than leaving the headroom that
newMultispeciesParams() uses to accommodate stochastic growth. This will be
revisited once these constructors gain a diffusion parameter, see
https://github.com/sizespectrum/mizer/issues/339.
The resulting MizerParams object can be projected forward using
project() like any other MizerParams object. When projecting
the community model it may be necessary to keep a small time step size
dt of around 0.1 to avoid any instabilities with the solver. You can
check for these numerical instabilities by plotting the biomass or abundance
through time after the projection.
An object of type MizerParams
K. H. Andersen,J. E. Beyer and P. Lundberg, 2009, Trophic and individual efficiencies of size-structured communities, Proceedings of the Royal Society, 276, 109-114
Other functions for setting up models:
newMultispeciesParams(),
newSingleSpeciesParams(),
newTraitParams()
params <- newCommunityParams()
sim <- project(params, t_max = 10)
plotBiomass(sim)
plotSpectra(sim, power = 2)
# More satiation. More mortality
params <- newCommunityParams(f0 = 0.8, z0 = 0.4)
sim <- project(params, t_max = 10)
plotBiomass(sim)
plotSpectra(sim, power = 2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.