View source: R/registerExtensions.R
| objectExtensions | R Documentation |
Get the extension chain stored in a mizer object
objectExtensions(object)
object |
A |
A named character vector of extensions, or an empty character vector if the object carries no extensions.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.