View source: R/ArraySpeciesBySize-class.R
| parsePlotLog | R Documentation |
Internal helper that resolves the various ways of specifying which axes
should use a logarithmic scale into a consistent pair of logical flags. It
is exported so that extension packages (such as mizerMR) can reuse it in
their own array plot() methods.
parsePlotLog(log, log_x = FALSE, log_y = FALSE)
log |
Either |
log_x, log_y |
Default logical flags used when |
A list with logical components log_x and log_y.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.