plot.ArrayTimeByResourceBySize: Plot method for 'ArrayTimeByResourceBySize' objects

View source: R/ArrayResourceBySize-class.R

plot.ArrayTimeByResourceBySizeR Documentation

Plot method for ArrayTimeByResourceBySize objects

Description

See plot() for an overview of the mizer plotting system. This method plots a single time slice, by first extracting it as an ArrayResourceBySize object and delegating to plot.ArrayResourceBySize(), which the further arguments in ... are passed on to.

Usage

## S3 method for class 'ArrayTimeByResourceBySize'
plot(x, time = NULL, ...)

Arguments

x

An ArrayTimeByResourceBySize object.

time

The time to display. Default (NULL) is the final time step.

...

Passed on to plot.ArrayResourceBySize().

Value

A ggplot2 object, unless return_data = TRUE, in which case a data frame is returned.

Examples


plot(NResource(NS_sim))


mizer documentation built on Aug. 24, 2026, 9:08 a.m.