View source: R/ArrayTimeBySpecies-class.R
| plot.ArrayTimeBySpecies | R Documentation |
ArrayTimeBySpecies objectsSee plot() for an overview of the mizer plotting system and the
arguments shared by all of its methods.
## S3 method for class 'ArrayTimeBySpecies'
plot(
x,
species = NULL,
tlim = c(NA, NA),
y_ticks = 6,
ylim = c(NA, NA),
total = FALSE,
background = TRUE,
highlight = NULL,
log_x = FALSE,
log_y = TRUE,
log = NULL,
return_data = FALSE,
...
)
x |
An |
species |
Character vector of species to include. |
tlim |
A numeric vector of length two providing lower and upper
limits for the time axis, e.g. |
y_ticks |
The approximate number of ticks desired on the y axis. |
ylim |
A numeric vector of length two providing lower and upper
limits for the value (y) axis. Use |
total |
A boolean value that determines whether the total is plotted
as well. The total is the total over every species the array holds,
whatever is drawn. Default is |
background |
A boolean value that determines whether background
species are included. Ignored if the model does not contain background
species. Default is |
highlight |
Name or vector of names of the species to be highlighted. |
log_x |
If |
log_y |
If |
log |
Character string specifying which axes should use log10
scales, in the same form as the base |
return_data |
If |
... |
Unused. |
A ggplot2 object, unless return_data = TRUE, in which case a
data frame is returned.
plot(getBiomass(NS_sim))
plot(getBiomass(NS_sim), species = c("Cod", "Herring"), total = TRUE)
plot(getYield(NS_sim), species = c("Cod", "Herring"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.