Learn R Programming

mizer (version 3.2.0)

plot.ArrayTimeBySpeciesBySize: Plot method for ArrayTimeBySpeciesBySize objects

Description

See plot() for an overview of the mizer plotting system and the arguments shared by all of its methods. This method plots a single time slice, by first extracting it as an ArraySpeciesBySize object and delegating to plot.ArraySpeciesBySize().

Usage

# S3 method for ArrayTimeBySpeciesBySize
plot(
  x,
  species = NULL,
  time = NULL,
  all.sizes = FALSE,
  highlight = NULL,
  return_data = FALSE,
  log_x = TRUE,
  log_y = FALSE,
  log = NULL,
  wlim = c(NA, NA),
  llim = c(NA, NA),
  ylim = c(NA, NA),
  size_axis = c("w", "l"),
  total = FALSE,
  background = TRUE,
  y_ticks = 6,
  ...
)

Value

A ggplot2 object, unless return_data = TRUE, in which case a data frame is returned.

Arguments

x

An ArrayTimeBySpeciesBySize object.

species

Character vector of species to include. NULL (default) means all species.

time

The time to display. Default (NULL) is the final time step.

all.sizes

If FALSE (default), values outside a species' size range (w_min to w_max) are removed.

highlight

Name or vector of names of the species to be highlighted.

return_data

If TRUE, return the data frame instead of the plot.

log_x

If TRUE, use a log10 x-axis. Default is TRUE.

log_y

If TRUE, use a log10 y-axis. Default is FALSE.

log

Character string specifying which axes should use log10 scales, in the same form as the base plot() argument. For example, "x", "y", "xy" or "". If supplied, this overrides log_x and log_y.

wlim

A numeric vector of length two providing lower and upper limits for the weight (x) axis. Use NA to refer to the existing minimum or maximum.

llim

A numeric vector of length two providing lower and upper limits for the length (x) axis when size_axis = "l". Use NA to refer to the existing minimum or maximum.

ylim

A numeric vector of length two providing lower and upper limits for the value (y) axis. Use NA to refer to the existing minimum or maximum.

size_axis

Whether to plot size as weight ("w", default) or length ("l"), using the allometric weight-length relationship.

total

A boolean value that determines whether the total over all selected species is plotted as well. Default is FALSE.

background

A boolean value that determines whether background species are included. Ignored if the model does not contain background species. Default is TRUE.

y_ticks

The approximate number of ticks desired on the y axis.

...

Unused.

Examples

Run this code
# \donttest{
plot(getFMort(NS_sim), time = 2010)
# }

Run the code above in your browser using DataLab