| plotCDF | R Documentation |
plotCDF() plots the cumulative distribution over body size from small to
large sizes. It uses the same spectra data preparation as plotSpectra():
the number density is multiplied by w^power and then integrated over size.
With normalise = TRUE, each curve is divided by its final value so that it
ends at 1.
plotCDF(
object,
species = NULL,
wlim = c(NA, NA),
llim = c(NA, NA),
ylim = c(NA, NA),
power = NULL,
biomass = NULL,
per_log_size = NULL,
total = FALSE,
resource = FALSE,
background = TRUE,
highlight = NULL,
normalise = TRUE,
log_x = TRUE,
log_y = FALSE,
log = NULL,
size_axis = c("w", "l"),
return_data = FALSE,
...
)
Unlike for plotSpectra(), the only choice that matters here is biomass:
whether to accumulate numbers or biomass. Whether a density is expressed
with respect to size or with respect to logarithmic size makes no difference
to its integral, because the change of variable cancels the factor of the
weight, and so plotCDF() does not accept per_log_size = TRUE.
plotlyCDF() is the interactive plotly version. To compare cumulative
distributions from two objects, use plotCDF2().
A ggplot2 object, unless return_data = TRUE, in which case a data
frame with the four variables 'w' (or 'l' if size_axis = "l"), 'value',
'Species', 'Legend' is returned. plotlyCDF() returns a plotly object.
plotSpectra(), plotCDF2()
Other plotting functions:
addPlot(),
animate(),
plot,
plot2(),
plotBiomass(),
plotCDF2(),
plotDiet(),
plotFMort(),
plotFeedingLevel(),
plotGrowthCurves(),
plotMizerParams,
plotMizerSim,
plotPredMort(),
plotRelative(),
plotSpectra(),
plotSpectra2(),
plotSpectraRelative(),
plotYield(),
plotYieldGear(),
plotYieldVsF(),
plotting_functions
plotCDF(NS_params, species = c("Cod", "Herring"))
plotCDF(NS_sim, power = 0, normalise = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.