| plotCDF2 | R Documentation |
plotCDF2() compares cumulative distributions from two MizerParams or
MizerSim objects in a single plot. Colours identify species or groups and
linetype identifies the object.
plotCDF2(
object1,
object2,
name1 = "First",
name2 = "Second",
species = NULL,
wlim = c(NA, NA),
llim = c(NA, NA),
ylim = c(NA, NA),
power = NULL,
biomass = NULL,
per_log_size = NULL,
total = FALSE,
resource = FALSE,
background = TRUE,
highlight = NULL,
normalise = TRUE,
log_x = TRUE,
log_y = FALSE,
log = NULL,
size_axis = c("w", "l"),
...
)
object1 |
First |
object2 |
Second |
name1, name2 |
Labels for the two objects, used in the linetype legend. |
species |
The species to be selected. Optional. By default all target species are selected. A vector of species names, or a numeric vector with the species indices, or a logical vector indicating for each species whether it is to be selected (TRUE) or not. |
wlim |
A numeric vector of length two providing lower and upper limits
for the w axis. Use NA for the default: the lower default is
|
llim |
A numeric vector of length two providing lower and upper limits
for the length axis when |
ylim |
A numeric vector of length two providing lower and upper limits
for the y axis. Use NA to auto-scale to the data range. Values below 1e-20
are always filtered out from the data regardless of |
power |
The number density is multiplied by the weight raised to
|
biomass |
Whether to plot the cumulative biomass ( |
per_log_size |
Only |
total |
A boolean value that determines whether the total is plotted as
well. The total is the total of everything the object holds — every
species and the resource — whatever is drawn, so it does not move when
|
resource |
A boolean value that determines whether resource is included. Default is FALSE. |
background |
A boolean value that determines whether background species are included. Ignored if the model does not contain background species. Default is TRUE. |
highlight |
Name or vector of names of the species to be highlighted by being plotted with thicker lines. |
normalise |
If |
log_x |
If |
log_y |
If |
log |
Character string specifying which axes should use a log10 scale,
in the same form as the base |
size_axis |
Whether to plot size as weight ( |
... |
Additional arguments passed to |
plotlyCDF2() is the interactive plotly version.
A ggplot2 object. plotlyCDF2() returns a plotly object.
plotSpectra(), plotCDF()
Other plotting functions:
addPlot(),
animate(),
plot,
plot2(),
plotBiomass(),
plotCDF(),
plotDiet(),
plotFMort(),
plotFeedingLevel(),
plotGrowthCurves(),
plotMizerParams,
plotMizerSim,
plotPredMort(),
plotRelative(),
plotSpectra(),
plotSpectra2(),
plotSpectraRelative(),
plotYield(),
plotYieldGear(),
plotYieldVsF(),
plotting_functions
sim1 <- project(NS_params, t_max = 10, progress_bar = FALSE)
sim2 <- project(NS_params, effort = 0.5, t_max = 10, progress_bar = FALSE)
plotCDF2(sim1, sim2, "Original", "Effort = 0.5")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.