Learn R Programming

mizer (version 3.0.0)

plotHover.ArraySpeciesBySize: Create a hover-enabled plotly plot from a mizer object

Description

Creates an interactive plotly version of a mizer plot. Can be called on any mizer array object (such as those returned by getEncounter(), getBiomass(), etc.) or on any mizer_plot object returned by the named plot functions such as plotBiomass(), plotSpectra(), etc.

Usage

# S3 method for ArrayTimeBySpecies
plotHover(x, ...)

plotHover(x, ...)

Value

A plotly object.

Arguments

x

A mizer_plot, ArraySpeciesBySize, ArrayTimeBySpecies, or ArrayTimeBySpeciesBySize object.

...

Arguments passed to the corresponding plot() method for mizer array objects, or to plotly::ggplotly() for mizer_plot objects.

See Also

plot(), plotBiomass(), plotSpectra(), plotting_functions

Examples

Run this code
# \donttest{
plotHover(getEncounter(NS_params))
# }
# \donttest{
plotHover(getBiomass(NS_sim))
# }
# \donttest{
plotHover(getFMort(NS_sim))
# }

Run the code above in your browser using DataLab