| plotM2 | R Documentation |
plotPredMort()
An alias provided for backward compatibility with mizer version <= 1.0
plotM2(
object,
species = NULL,
all.sizes = FALSE,
highlight = NULL,
wlim = c(NA, NA),
llim = c(NA, NA),
size_axis = c("w", "l"),
return_data = FALSE,
log_x = TRUE,
log_y = FALSE,
log = NULL,
...
)
object |
An object of class MizerSim or MizerParams. |
species |
The species to be selected. Optional. By default all target species are selected. A vector of species names, or a numeric vector with the species indices, or a logical vector indicating for each species whether it is to be selected (TRUE) or not. |
all.sizes |
If TRUE, then predation mortality is plotted also for sizes outside a species' size range. Default FALSE. |
highlight |
Name or vector of names of the species to be highlighted. |
wlim |
A numeric vector of length two providing lower and upper limits
for the weight (x) axis. Use |
llim |
A numeric vector of length two providing lower and upper limits
for the length (x) axis when |
size_axis |
Whether to plot size as weight ( |
return_data |
A boolean value that determines whether the formatted data used for the plot is returned instead of the plot itself. Default is FALSE. |
log_x |
If |
log_y |
If |
log |
Character string specifying which axes should use log10 scales,
in the same form as the base |
... |
Further arguments used by only some of the methods: For
|
A ggplot2 object, unless return_data = TRUE, in which case a data
frame with the three variables 'w' (or 'l' if size_axis = "l"), 'value',
'Species' is returned.
plotting_functions, getPredMort()
Other plotting functions:
addPlot(),
animate(),
plot,
plot2(),
plotBiomass(),
plotCDF(),
plotCDF2(),
plotDiet(),
plotFMort(),
plotFeedingLevel(),
plotGrowthCurves(),
plotMizerParams,
plotMizerSim,
plotRelative(),
plotSpectra(),
plotSpectra2(),
plotSpectraRelative(),
plotYield(),
plotYieldGear(),
plotYieldVsF(),
plotting_functions
params <- NS_params
sim <- project(params, effort=1, t_max=20, t_save = 2, progress_bar = FALSE)
plotPredMort(sim)
plotPredMort(sim, time_range = 10:20)
# Returning the data frame
fr <- plotPredMort(sim, return_data = TRUE)
str(fr)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.