plotMizerParams: Summary plot for 'MizerParams' objects

plotMizerParamsR Documentation

Summary plot for MizerParams objects

Description

Produces 3 plots in the same window: abundance spectra, feeding level and predation mortality of each species against size. This method just puts the plots generated by plotFeedingLevel(), plotPredMort() and plotSpectra() all in one window.

Usage

## S3 method for class 'MizerParams'
plot(x, ...)

Arguments

x

An object of class MizerParams

...

Arguments passed on to the individual plotting functions plotFeedingLevel(), plotSpectra() and plotPredMort(). The arguments that describe the plotted spectrum (power, biomass, per_log_size and resource) go to plotSpectra() only, because they mean nothing to a rate.

Value

A viewport object

See Also

plotting_functions

Other plotting functions: addPlot(), animate(), plot, plot2(), plotBiomass(), plotCDF(), plotCDF2(), plotDiet(), plotFMort(), plotFeedingLevel(), plotGrowthCurves(), plotMizerSim, plotPredMort(), plotRelative(), plotSpectra(), plotSpectra2(), plotSpectraRelative(), plotYield(), plotYieldGear(), plotYieldVsF(), plotting_functions

Examples


params <-  NS_params
plot(params)


mizer documentation built on Aug. 31, 2026, 5:08 p.m.