plotMizerSim: Summary plot for 'MizerSim' objects

plotMizerSimR Documentation

Summary plot for MizerSim objects

Description

After running a projection, produces 5 plots in the same window: feeding level, abundance spectra, predation mortality and fishing mortality of each species by size; and biomass of each species through time. This method just puts the plots generated by plotBiomass(), plotFeedingLevel(), plotSpectra(), plotPredMort() and plotFMort() all in one window.

Usage

## S3 method for class 'MizerSim'
plot(x, ...)

Arguments

x

An object of class MizerSim

...

Arguments passed on to the individual plotting functions plotBiomass(), plotFeedingLevel(), plotSpectra(), plotPredMort() and plotFMort(). The arguments that describe the plotted spectrum (power, biomass, per_log_size and resource) go to plotSpectra() only, because they mean nothing to a rate.

Value

A viewport object

See Also

plotting_functions

Other plotting functions: addPlot(), animate(), plot, plot2(), plotBiomass(), plotCDF(), plotCDF2(), plotDiet(), plotFMort(), plotFeedingLevel(), plotGrowthCurves(), plotMizerParams, plotPredMort(), plotRelative(), plotSpectra(), plotSpectra2(), plotSpectraRelative(), plotYield(), plotYieldGear(), plotYieldVsF(), plotting_functions

Examples


params <-  NS_params
sim <- project(params, effort=1, t_max=20, t_save = 2, progress_bar = FALSE)
plot(sim)


mizer documentation built on Aug. 31, 2026, 5:08 p.m.