| plotSpectraRelative | R Documentation |
plotSpectraRelative() plots the difference between the spectra relative to
their average. If we denote the number density from the first object as
N_1(w) and that from the second object as N_2(w), then this
plot shows
2 (N_2(w) - N_1(w)) / (N_2(w) + N_1(w)).
Note that it does not matter whether the relative difference is calculated
for number density, biomass density, or biomass density in log weight,
because the factors of w by which the densities differ cancel out in
the relative difference.
plotSpectraRelative(
object1,
object2,
species = NULL,
wlim = c(NA, NA),
llim = c(NA, NA),
ylim = c(NA, NA),
total = FALSE,
resource = TRUE,
background = TRUE,
highlight = NULL,
log_x = TRUE,
size_axis = c("w", "l"),
...
)
object1 |
First |
object2 |
Second |
species |
The species to be selected. Optional. By default all target species are selected. A vector of species names, or a numeric vector with the species indices, or a logical vector indicating for each species whether it is to be selected (TRUE) or not. |
wlim |
A numeric vector of length two providing lower and upper limits
for the w axis. Use NA for the default: the lower default is
|
llim |
A numeric vector of length two providing lower and upper limits
for the length axis when |
ylim |
A numeric vector of length two providing lower and upper limits
for the y axis (the relative difference). Use |
total |
A boolean value that determines whether the total is plotted as
well. The total is the total of everything the object holds — every
species and the resource — whatever is drawn, so it does not move when
|
resource |
A boolean value that determines whether resource is included. Default is TRUE. |
background |
A boolean value that determines whether background species are included. Ignored if the model does not contain background species. Default is TRUE. |
highlight |
Name or vector of names of the species to be highlighted by being plotted with thicker lines. |
log_x |
If |
size_axis |
Whether to plot size as weight ( |
... |
Additional arguments passed to |
plotlySpectraRelative() is the interactive plotly version.
A ggplot2 object. plotlySpectraRelative() returns a plotly object.
plotting_functions, plotSpectra(), plotSpectra2()
Other plotting functions:
addPlot(),
animate(),
plot,
plot2(),
plotBiomass(),
plotCDF(),
plotCDF2(),
plotDiet(),
plotFMort(),
plotFeedingLevel(),
plotGrowthCurves(),
plotMizerParams,
plotMizerSim,
plotPredMort(),
plotRelative(),
plotSpectra(),
plotSpectra2(),
plotYield(),
plotYieldGear(),
plotYieldVsF(),
plotting_functions
sim1 <- project(NS_params, t_max = 10, progress_bar = FALSE)
sim2 <- project(NS_params, effort = 0.5, t_max = 10, progress_bar = FALSE)
plotSpectraRelative(sim1, sim2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.