| plotYield | R Documentation |
After running a projection, the total yield of each species across all
fishing gears can be plotted against time. The yield is obtained with
getYield().
plotYield(
object,
sim2 = NULL,
species = NULL,
total = FALSE,
log_x = FALSE,
log_y = TRUE,
log = NULL,
ylim = c(NA, NA),
tlim = c(NA, NA),
highlight = NULL,
return_data = FALSE,
...
)
object |
An object of class MizerSim |
sim2 |
An optional second object of class MizerSim. If this is provided its yields will be shown on the same plot in bolder lines. |
species |
The species to be selected. Optional. By default all target species are selected. A vector of species names, or a numeric vector with the species indices, or a logical vector indicating for each species whether it is to be selected (TRUE) or not. |
total |
A boolean value that determines whether the total yield from all species is plotted as well. Default is FALSE. |
log_x |
If |
log_y |
If |
log |
Character string specifying which axes should use log10 scales,
in the same form as the base |
ylim |
A numeric vector of length two providing lower and upper limits
for the y axis. Use |
tlim |
A numeric vector of length two providing lower and upper limits
for the time axis, e.g. |
highlight |
Name or vector of names of the species to be highlighted. |
return_data |
A boolean value that determines whether the formatted data used for the plot is returned instead of the plot itself. Default is FALSE. |
... |
Arguments passed to |
A ggplot2 object, unless return_data = TRUE, in which case a data
frame with the three variables 'Year', 'Yield', 'Species' is returned. If
sim2 is supplied, the data frame also has a 'Simulation' variable.
plotting_functions, getYield()
Other plotting functions:
addPlot(),
animate(),
plot,
plot2(),
plotBiomass(),
plotCDF(),
plotCDF2(),
plotDiet(),
plotFMort(),
plotFeedingLevel(),
plotGrowthCurves(),
plotMizerParams,
plotMizerSim,
plotPredMort(),
plotRelative(),
plotSpectra(),
plotSpectra2(),
plotSpectraRelative(),
plotYieldGear(),
plotYieldVsF(),
plotting_functions
params <- NS_params
sim <- project(params, effort = 1, t_max = 20, t_save = 0.2, progress_bar = FALSE)
plotYield(sim)
plotYield(sim, species = c("Cod", "Herring"), total = TRUE)
# Comparing with yield from twice the effort
sim2 <- project(params, effort=2, t_max=20, t_save = 0.2, progress_bar = FALSE)
plotYield(sim, sim2, species = c("Cod", "Herring"), log = FALSE)
# Returning the data frame
fr <- plotYield(sim, return_data = TRUE)
str(fr)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.