| plot_cdf | R Documentation |
Internal worker shared by the plotCDF() methods. It integrates the spectra
data over size (optionally normalising), converts to a length axis if
requested, and either returns the data or draws the plot via
plotDataFrame().
plot_cdf(
plot_dat,
params,
power,
normalise,
log_x,
log_y,
wlim,
llim,
ylim,
highlight,
size_axis,
return_data
)
plot_dat |
Spectra plotting data as produced for |
params |
A MizerParams object. |
power |
The power of weight that the abundance was multiplied by, used for the y-axis label. |
normalise |
If |
log_x, log_y |
Logical flags for log10 axes. |
wlim, llim |
Numeric vectors of length two giving the weight and length limits. |
ylim |
Numeric vector of length two giving the y-axis limits. |
highlight |
Name or vector of names of species to be highlighted. |
size_axis |
Either |
return_data |
If |
A mizer_plot (ggplot2) object, or the data frame if
return_data = TRUE.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.