| plot_growth_curves | R Documentation |
Internal worker shared by the plotGrowthCurves() methods. It computes the
modelled size at age, optionally adds a von Bertalanffy curve and observed
size-at-age data, and draws the plot.
plot_growth_curves(
params,
species,
max_age,
percentage,
species_panel,
highlight,
log_x,
log_y,
size_at_age,
return_data
)
params |
A MizerParams object. |
species |
The species to be plotted. |
max_age |
The age up to which to plot the growth curve. |
percentage |
If |
species_panel |
If |
highlight |
Name or vector of names of species to be highlighted. |
log_x, log_y |
Logical flags for log10 axes. |
size_at_age |
Optional data frame of observed size-at-age data. |
return_data |
If |
A mizer_plot (ggplot2) object, or the plotting data frame if
return_data = TRUE.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.