plot_size_tooltip: Assemble the tooltip variables for a size-axis plot

View source: R/plots.R

plot_size_tooltipR Documentation

Assemble the tooltip variables for a size-axis plot

Description

Assemble the tooltip variables for a size-axis plot

Usage

plot_size_tooltip(size_axis, before = NULL, after = NULL)

Arguments

size_axis

Either "w" (weight) or "l" (length).

before, after

Optional character vectors of variable names to place before and after the size variable in the tooltip.

Value

A character vector of tooltip variable names.


mizer documentation built on Aug. 31, 2026, 5:08 p.m.