plot_size_xlim: Choose the x-axis limits for a given size axis

View source: R/plots.R

plot_size_xlimR Documentation

Choose the x-axis limits for a given size axis

Description

Choose the x-axis limits for a given size axis

Usage

plot_size_xlim(wlim, size_axis, llim = c(NA, NA))

Arguments

wlim

Numeric vector of length two giving the weight limits.

size_axis

Either "w" (weight) or "l" (length).

llim

Numeric vector of length two giving the length limits.

Value

llim for a length axis, otherwise wlim.


mizer documentation built on Aug. 24, 2026, 9:08 a.m.