prepare_MizerScan_plot_data: Prepare the data frame for plotting a MizerScan

View source: R/MizerScan-class.R

prepare_MizerScan_plot_dataR Documentation

Prepare the data frame for plotting a MizerScan

Description

Prepare the data frame for plotting a MizerScan

Usage

prepare_MizerScan_plot_data(x, species = NULL)

Arguments

x

A MizerScan object.

species

The series to keep, or NULL for all of them.

Value

A data frame with the x, y and grouping variable in the first three columns, as plotDataFrame() requires.


mizer documentation built on Aug. 24, 2026, 9:08 a.m.