print.mizer_plot: Print a mizer plot

View source: R/plots.R

print.mizer_plotR Documentation

Print a mizer plot

Description

Suppresses the uninformative ggplot2 warning about log transformations introducing infinite values, which occurs when zero values are present on a logged axis.

Usage

## S3 method for class 'mizer_plot'
print(x, ...)

Arguments

x

A mizer_plot object.

...

Further arguments passed to the ggplot2 print method.

Value

The plot object, invisibly.


mizer documentation built on Aug. 31, 2026, 5:08 p.m.