View source: R/manipulate_species.R
| removeSpecies | R Documentation |
This function simply removes all entries from the MizerParams object that refer to the selected species. It does not recalculate the steady state for the remaining species or retune their reproductive efficiency.
removeSpecies(params, species, ...)
params |
A mizer params object for the original system. |
species |
The species to be removed. A vector of species names, or a numeric vector of species indices, or a logical vector indicating for each species whether it is to be removed (TRUE) or not. |
... |
Currently unused. |
If a gear was targeting only the removed species, then this function will
NOT remove that gear. If you want to also remove that gear then you can do
that by calling setFishing().
An object of type MizerParams
addSpecies(), renameSpecies()
params <- NS_params
species_params(params)$species
params <- removeSpecies(params, c("Cod", "Haddock"))
species_params(params)$species
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.