View source: R/manipulate_species.R
| renameGear | R Documentation |
Changes the names of gears in a MizerParams object. This involves for example changing the gear dimension names of selectivity and catchability arrays appropriately.
renameGear(params, replace, ...)
params |
A mizer params object |
replace |
A named character vector, with new names as values, and old names as names. |
... |
Currently unused. |
An object of type MizerParams
renameSpecies()
replace <- c(Industrial = "Trawl", Otter = "Beam_Trawl")
params <- renameGear(NS_params, replace)
gear_params(params)$gear
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.