scan_plot_params: The params object to use when plotting a MizerScan

View source: R/MizerScan-class.R

scan_plot_paramsR Documentation

The params object to use when plotting a MizerScan

Description

Series that are not species have no colour in the model, and plotDataFrame() silently drops any legend level it cannot find a colour for. So any such series is given a colour here, using the ordinary setColours() interface, which also leaves the user free to choose a different one.

Usage

scan_plot_params(x, plot_dat)

Arguments

x

A MizerScan object.

plot_dat

The data frame that will be plotted.

Value

A MizerParams object with a colour for every series in plot_dat.


mizer documentation built on Aug. 24, 2026, 9:08 a.m.