select_gear_rows: The gear params rows whose fishing mortality is to be varied

View source: R/scan_setters.R

select_gear_rowsR Documentation

The gear params rows whose fishing mortality is to be varied

Description

The gear params rows whose fishing mortality is to be varied

Usage

select_gear_rows(gp, species, gear = NULL)

Arguments

gp

The gear params data frame, with a character gear column.

species

The target species.

gear

The selected gear, or NULL for all gears catching the species.

Value

An integer vector of row indices.


mizer documentation built on Aug. 31, 2026, 5:08 p.m.