| setColours | R Documentation |
Used for setting the colour and type of lines representing "Total",
"Resource", "Fishing", "Background", "External" and possibly other categories
in plots.
setColours(params, colours)
getColours(params)
setLinetypes(params, linetypes)
getLinetypes(params)
params |
A MizerParams object |
colours |
A named list or named vector of line colours. |
linetypes |
A named list or named vector of linetypes. |
Colours for names that already had a colour set for them will be overwritten by the colour you specify. Colours for names that did not yet have a colour will be appended to the list of colours.
If a name coincides with the name of a species, the linecolour (for
setColours()) or linetype (for setLinetypes()) entry for that species
in species_params and given_species_params is updated as well, so that
the choice persists with the species. Alternatively you can set the
linecolour and linetype variables in the species parameter data frame
directly, see the example below.
You can use the same colours in your own ggplot2 plots by adding
scale_colour_manual(values = getColours(params)) to your plot. Similarly
you can use the linetypes with
scale_linetype_manual(values = getLinetypes(params)).
setColours: The MizerParams object with updated line colours
getColours(): A named vector of colours
setLinetypes(): The MizerParams object with updated linetypes
getLinetypes(): A named vector of linetypes
params <- setColours(NS_params, list("Resource" = "red","Total" = "#0000ff"))
params <- setLinetypes(NS_params, list("Total" = "dotted"))
# Set colours and linetypes for species, either via setColours()/
# setLinetypes() or directly via the species parameter data frame
params <- setColours(params, list("Cod" = "black"))
species_params(params)["Cod", "linetype"] <- "dashed"
plotSpectra(params, total = TRUE)
getColours(params)
getLinetypes(params)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.