View source: R/setExtEncounter.R
| setExtEncounter | R Documentation |
You will usually not need to call this function directly. Instead change
the E_ext and n species parameters with
given_species_params(params) <- and let mizer recalculate the external
encounter rate for you. Call setExtEncounter() directly only if you want
to impose a different functional form for the size dependence of the
external encounter rate. See vignette("guide-change-parameters")
for a full explanation of when to reach for which level of the model.
setExtEncounter(params, ext_encounter = NULL, reset = FALSE, ...)
ext_encounter(params)
ext_encounter(params) <- value
params |
MizerParams |
ext_encounter |
Optional. An array (species x size) holding the external
encounter rate. If not supplied, a default is calculated from the |
reset |
If set to TRUE, then the external encounter rate will be reset to the value calculated from the species parameters, even if it was previously overwritten with a custom value. If set to FALSE (default) then a recalculation from the species parameters will take place only if no custom value has been set. |
... |
Unused |
value |
ext_encounter |
setExtEncounter(): A MizerParams object with updated external encounter
rate.
ext_encounter(): An ArraySpeciesBySize object (species x size)
with the external encounter rate.
The external encounter rate is the rate at which a predator encounters food that is not explicitly modelled. It is a rate with units mass/year.
The ext_encounter argument allows you to specify an external encounter rate
that depends on species and body size. You can see an example of this in
the Examples section of the help page for setExtEncounter().
If the ext_encounter argument is not supplied, then the external encounter
rate is calculated as a power law:
E_{ext.i}(w) = E_{ext.i}\, w^{n_i}.
The coefficient E_{ext.i} is taken from the E_ext column of the
species parameter data frame, which defaults to 0. The exponent n_i is
taken from the n column of the species parameter data frame.
If the ext_encounter slot has a comment and reset = FALSE, then a
recalculation from the species parameters is suppressed and a message is
issued if the recalculated values would differ from the stored ones.
Other functions for setting parameters:
gear_params(),
setExtDiffusion(),
setExtMort(),
setFishing(),
setInteraction(),
setMaxIntakeRate(),
setMetabolicRate(),
setParams(),
setPredKernel(),
setReproduction(),
setSearchVolume(),
species_params(),
use_predation_diffusion()
params <- newMultispeciesParams(NS_species_params)
#### Setting allometric encounter rate #######################
# Set coefficient for each species. Here we choose 0.1 for each species
encounter_pre <- rep(0.1, nrow(species_params(params)))
# Multiply by power of size with exponent, here chosen to be 3/4
# The outer() function makes it an array species x size
allo_encounter <- outer(encounter_pre, w(params)^(3/4))
# Change the external encounter rate in the params object
ext_encounter(params) <- allo_encounter
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.