setMaxIntakeRate: Set maximum intake rate

View source: R/setMaxIntakeRate.R

setMaxIntakeRateR Documentation

Set maximum intake rate

Description

You will usually not need to call this function directly. Instead change the h and n species parameters with ⁠given_species_params(params) <-⁠ and let mizer recalculate the maximum intake rate for you. Call setMaxIntakeRate() directly only if you want to impose a different functional form for the size dependence of the intake rate. See vignette("guide-change-parameters") for a full explanation of when to reach for which level of the model.

Usage

setMaxIntakeRate(params, intake_max = NULL, reset = FALSE, ...)

intake_max(params)

intake_max(params) <- value

Arguments

params

MizerParams

intake_max

Optional. An array (species x size) holding the maximum intake rate for each species at size. If not supplied, a default is set as described in the section "Setting maximum intake rate".

reset

If set to TRUE, then the intake rate will be reset to the value calculated from the species parameters, even if it was previously overwritten with a custom value. If set to FALSE (default) then a recalculation from the species parameters will take place only if no custom value has been set.

...

Unused

value

intake_max

Value

setMaxIntakeRate(): A MizerParams object with updated maximum intake rate.

intake_max(): An ArraySpeciesBySize object (species x size) with the maximum intake rate.

Setting maximum intake rate

The maximum intake rate h_i(w) of an individual of species i and weight w determines the feeding level, calculated with getFeedingLevel(). It is measured in grams/year.

If the intake_max argument is not supplied, then the maximum intake rate is set to

h_i(w) = h_i w^{n_i}.

The values of h_i (the maximum intake rate of an individual of size 1 gram) and n_i (the allometric exponent for the intake rate) are taken from the h and n columns in the species parameter dataframe. If the h column is not supplied in the species parameter dataframe, it is calculated by the get_h_default() function. If the n column is not supplied, a default of n_i = 3/4 is used.

If h_i is set to Inf, fish of species i will consume all encountered food.

If the intake_max slot has a comment and reset = FALSE, then a recalculation from the species parameters is suppressed and a message is issued if the recalculated values would differ from the stored ones.

See Also

Other functions for setting parameters: gear_params(), setExtDiffusion(), setExtEncounter(), setExtMort(), setFishing(), setInteraction(), setMetabolicRate(), setParams(), setPredKernel(), setReproduction(), setSearchVolume(), species_params(), use_predation_diffusion()

Examples

# Inspect the current maximum intake rate
intake_max(NS_params)["Cod", 1:5]

# Increase intake rate for Cod by 50%
im <- intake_max(NS_params)
im["Cod", ] <- im["Cod", ] * 1.5
params <- setMaxIntakeRate(NS_params, intake_max = im)
intake_max(params)["Cod", 1:5]

mizer documentation built on Aug. 31, 2026, 5:08 p.m.