View source: R/setSearchVolume.R
| setSearchVolume | R Documentation |
You will usually not need to call this function directly. Instead change
the gamma and q species parameters with given_species_params(params) <-
and let mizer recalculate the search volume for you. Call setSearchVolume()
directly only if you want to impose a different functional form for the size
dependence of the search volume. See vignette("guide-change-parameters")
for a full explanation of when to reach for which level of the model.
setSearchVolume(params, search_vol = NULL, reset = FALSE, ...)
search_vol(params)
search_vol(params) <- value
params |
MizerParams |
search_vol |
Optional. An array (species x size) holding the search volume for each species at size. If not supplied, a default is set as described in the section "Setting search volume". |
reset |
If set to TRUE, then the search volume will be reset to the value calculated from the species parameters, even if it was previously overwritten with a custom value. If set to FALSE (default) then a recalculation from the species parameters will take place only if no custom value has been set. |
... |
Unused |
value |
search_vol |
setSearchVolume(): A MizerParams object with updated search volume.
search_vol(): An ArraySpeciesBySize object (species x size)
holding the search volume.
The search volume \gamma_i(w) of an individual of species i
and weight w multiplies the predation kernel when
calculating the encounter rate in getEncounter() and the
predation rate in getPredRate().
The name "search volume" is a bit misleading, because \gamma_i(w) does
not have units of volume. It is simply a parameter that determines the rate
of predation. Its units depend on your choice, see section "Units in mizer".
If you have chosen to work with total abundances, then it is a rate with units
1/year. If you have chosen to work with abundances per m^2 then it has units
of m^2/year. If you have chosen to work with abundances per m^3 then it has
units of m^3/year.
If the search_vol argument is not supplied, then the search volume is
set to
\gamma_i(w) = \gamma_i w^q_i.
The values of \gamma_i (the search volume at 1g) and q_i (the
allometric exponent of the search volume) are taken from the gamma and
q columns in the species parameter dataframe. If the gamma
column is not supplied in the species parameter dataframe, a default is
calculated by the get_gamma_default() function. If the q column is not
supplied, a default of lambda - 2 + n is used. Note that only
for predators of size w = 1 gram is the value of the species parameter
\gamma_i the same as the value of the search volume \gamma_i(w).
If the search_vol slot has a comment and reset = FALSE, then a
recalculation from the species parameters is suppressed and a message is
issued if the recalculated values would differ from the stored ones.
Other functions for setting parameters:
gear_params(),
setExtDiffusion(),
setExtEncounter(),
setExtMort(),
setFishing(),
setInteraction(),
setMaxIntakeRate(),
setMetabolicRate(),
setParams(),
setPredKernel(),
setReproduction(),
species_params(),
use_predation_diffusion()
# Inspect the current search volume
search_vol(NS_params)["Cod", 1:5]
# Double the search volume for all species
sv <- search_vol(NS_params) * 2
params <- setSearchVolume(NS_params, search_vol = sv)
search_vol(params)["Cod", 1:5]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.