| spectra_y_label | R Documentation |
Y-axis label for a size-spectrum plot
spectra_y_label(
power,
size_axis = "w",
biomass = power >= 1,
per_log_size = power == 2
)
power |
The power of weight that the abundance was multiplied by. |
size_axis |
Either |
biomass |
Whether the quantity is a biomass density rather than a
number density. Defaults to |
per_log_size |
Whether the quantity is a density with respect to
logarithmic size. Defaults to |
A character string for the y-axis label.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.