str: Display the structure of mizer objects

strR Documentation

Display the structure of mizer objects

Description

Mizer provides str() methods for MizerParams() and MizerSim() objects, as well as ArraySpeciesBySize(), ArrayTimeBySpecies() and ArrayTimeBySpeciesBySize() objects. These methods produce a clean, compact overview of the object's structure without polluting the console with large amounts of internal data.

Usage

## S3 method for class 'ArraySpeciesBySize'
str(object, ...)
## S3 method for class 'ArrayTimeBySpecies'
str(object, ...)
## S3 method for class 'ArrayTimeBySpeciesBySize'
str(object, ...)
## S3 method for class 'MizerSim'
str(object, max.level = NA, ...)
## S3 method for class 'MizerParams'
str(object, max.level = NA, ...)

Arguments

object

The object to display the structure of.

max.level

Maximum level of nesting to print. Defaults to NA (no limit).

...

Further arguments. They are passed to the default str() method.

Value

NULL, invisibly.

See Also

print(), as.data.frame(), summary(), plot(), MizerParams(), MizerSim(), ArraySpeciesBySize(), ArrayTimeBySpecies(), ArrayTimeBySpeciesBySize()

Examples


str(NS_params)
str(NS_sim)
str(getEncounter(NS_params))


mizer documentation built on Aug. 24, 2026, 9:08 a.m.