Learn R Programming

mizer (version 3.2.0)

ArrayResourceBySize: S3 class for resource size spectra

Description

Several functions in mizer return a vector over the full size grid holding a resource-related quantity such as the resource number density, the resource mortality, the intrinsic resource birth rate or carrying capacity. The ArrayResourceBySize class wraps these vectors to provide convenient print(), summary(), plot(), and as.data.frame() methods.

Usage

ArrayResourceBySize(x, value_name = NULL, units = NULL, params = NULL)

is.ArrayResourceBySize(x)

Value

An ArrayResourceBySize object (inherits from numeric).

is.ArrayResourceBySize() returns TRUE if x is an ArrayResourceBySize object, FALSE otherwise.

Arguments

x

A numeric vector over the full size grid. For is.ArrayResourceBySize(), any object to test.

value_name

A string giving the human-readable name for the value.

units

A string giving the units (e.g. "1/year").

params

A MizerParams object. Used for the resource colour and the size grid in the plot() method.

Details

An ArrayResourceBySize object behaves just like a regular numeric vector for arithmetic operations and subsetting. It carries three lightweight attributes:

  • value_name – a human-readable name for the value (e.g. "Resource mortality").

  • units – the units of the value (e.g. "1/year").

  • params – the MizerParams object that the value was computed from.

See Also

Examples

Run this code
# \donttest{
mort <- getResourceMort(NS_params)
is.ArrayResourceBySize(mort)
summary(mort)
plot(mort)
# }

Run the code above in your browser using DataLab