Several functions in mizer return a vector over the full size grid holding
a resource-related quantity such as the resource number density, the
resource mortality, the intrinsic resource birth rate or carrying capacity.
The ArrayResourceBySize class wraps these vectors to provide convenient
print(), summary(), plot(), and as.data.frame() methods.