Learn R Programming

mizer (version 3.0.0)

NOther: Time series of other components

Description

Fetch the simulation results for other components over time.

Usage

NOther(sim)

finalNOther(sim)

Value

For NOther: A list array indexed by time and component that stores the projected values for other ecosystem components.

For finalNOther: A named list holding the values of other ecosystem components at the end of the simulation

Arguments

sim

A MizerSim object

See Also

Other extension tools: clearExtensionChain(), coerceToExtensionClass(), getRegisteredExtensions(), initialNOther<-(), registerExtension(), registerExtensions(), setComponent(), setRateFunction()