Fetch the simulation results for other components over time.
NOther(sim)finalNOther(sim)
For NOther: A list array indexed by time and component that stores the projected
values for other ecosystem components.
For finalNOther: A named list holding the values of other ecosystem components at the
end of the simulation
A MizerSim object
Other extension tools:
clearExtensionChain(),
coerceToExtensionClass(),
getRegisteredExtensions(),
initialNOther<-(),
registerExtension(),
registerExtensions(),
setComponent(),
setRateFunction()