| NS_species_params | R Documentation |
This data set is based on species in the North Sea (Blanchard et al.). It is
a data.frame that contains all the necessary information to be used by the
MizerParams() constructor. As there is no gear column, each species is
assumed to be fished by a separate gear.
NS_species_params
A data frame with 12 rows and 7 columns. Each row is a species.
Name of the species
Computational upper size boundary, defaulting to 1.5 * w_inf.
Size at maturity
Size preference ratio
Width of the size-preference
Maximum reproduction rate
The von Bertalanffy k parameter
The von Bertalanffy asymptotic size. This is the required maximum-size parameter.
Blanchard et al.
params <- newMultispeciesParams(NS_species_params)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.