NS_species_params: Example species parameter set based on the North Sea
Description
This data set is based on species in the North Sea (Blanchard et al.). It is
a data.frame that contains all the necessary information to be used by the
MizerParams() constructor. As there is no gear column, each species is
assumed to be fished by a separate gear.
Usage
NS_species_params
Arguments
Format
A data frame with 12 rows and 7 columns. Each row is a species.
species
Name of the species
w_max
Computational upper size boundary, defaulting to 1.5 * w_inf.
w_mat
Size at maturity
beta
Size preference ratio
sigma
Width of the size-preference
R_max
Maximum reproduction rate
k_vb
The von Bertalanffy k parameter
w_inf
The von Bertalanffy asymptotic size. This is the required
maximum-size parameter.