NS_species_params_gears: Example species parameter set based on the North Sea with different gears
Description
This data set is based on species in the North Sea (Blanchard et al.).
It is similar to the data set NS_species_params except that
this one has an additional column specifying the fishing gear that
operates on each species.
Usage
NS_species_params_gears
Arguments
Format
A data frame with 12 rows and 8 columns. Each row is a species.
species
Name of the species
w_max
Computational upper size boundary, defaulting to 1.5 * w_inf.
w_mat
Size at maturity
beta
Size preference ratio
sigma
Width of the size-preference
R_max
Maximum reproduction rate
k_vb
The von Bertalanffy k parameter
w_inf
The von Bertalanffy asymptotic size. This is the required
maximum-size parameter.