View source: R/MizerScan-class.R
| add_scan_annotations | R Documentation |
Add the annotation layers to a MizerScan plot
add_scan_annotations(
p,
x,
plot_dat,
reference_lines = TRUE,
mark_max = FALSE,
show_unsettled = TRUE
)
p |
The ggplot object so far. |
x |
The MizerScan object. |
plot_dat |
The data frame being plotted. |
reference_lines |
TRUE to use the stored reference lines, FALSE for none, or a named numeric vector to use instead. |
mark_max |
Whether to mark where each series attains its maximum. |
show_unsettled |
Whether to mark the scan values that did not settle. |
The ggplot object with the extra layers, still a mizer_plot.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.