| age_mat | R Documentation |
Uses the size-dependent growth rate and the size at maturity to calculate the age at maturity.
age_mat(params, ...)
params |
A MizerParams object |
... |
Currently unused. |
Using that by definition of the growth rate g(w) = dw/dt we have that
\mathrm{age_{mat}} = \int_0^{w_{mat}.}\frac{dw}{g(w)}
In the implementation this integral is approximated on the model size grid by
summing dw / g(w) over all size bins with w < w_mat.
A named vector. The names are the species names and the values are the ages at maturity.
age_mat(NS_params)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.