Learn R Programming

mizer (version 3.0.0)

age_mat: Calculate age at maturity

Description

Uses the size-dependent growth rate and the size at maturity to calculate the age at maturity.

Usage

age_mat(params, ...)

Value

A named vector. The names are the species names and the values are the ages at maturity.

Arguments

params

A MizerParams object

...

Currently unused.

Details

Using that by definition of the growth rate \(g(w) = dw/dt\) we have that $$\mathrm{age_{mat}} = \int_0^{w_{mat}.}\frac{dw}{g(w)}$$ In the implementation this integral is approximated on the model size grid by summing dw / g(w) over all size bins with w < w_mat.

Examples

Run this code
age_mat(NS_params)

Run the code above in your browser using DataLab