A proportion belongs on a linear axis, so a plot of one turns log_y off
unless the caller asked for a particular axis. Called before
parsePlotLog(), which is why it also has to check log.
array_log_y(x, log_y, log, given)The log_y to use.
A mizer array object.
The log_y argument of the plot method.
The log argument of the plot method.
Whether the caller supplied log_y (i.e. !missing(log_y)).