| as_series_matrix | R Documentation |
Bring what a value function returned into a time by series matrix
as_series_matrix(x, default_name = "Value")
x |
The return value of a |
default_name |
The column name to use for a single unnamed series. |
A matrix with time in the rows and the series in the columns.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.