| broadcast_dims | R Documentation |
Internal helper for sizeIntegral(). Replicates x along the dimensions it
does not have and permutes its dimensions into the order given by
target_labels, so that arrays with different dimensions can be multiplied
together elementwise.
broadcast_dims(x, labels, target_labels, extent)
x |
An array, vector or scalar. |
labels |
The dimension labels of |
target_labels |
The dimension labels of the result. Must contain all of
|
extent |
A named vector giving the extent of each label. |
An array with dimensions extent[target_labels].
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.