Learn R Programming

mizer (version 3.0.0)

calc_selectivity: Calculate selectivity from gear parameters

Description

This function calculates the selectivity for each gear, species and size from the gear parameters. It is called by setFishing() when the selectivity is not set by the user. The returned array is initialised to zero, so gear-species combinations that are not listed in gear_params(params) remain zero. For each listed combination the function named in sel_func is called with w = params@w, the corresponding species parameters, and the selectivity parameters from the matching row in gear_params(params).

Usage

calc_selectivity(params)

Value

An array (gear x species x size) with the selectivity values

Arguments

params

A MizerParams object

Examples

Run this code
params <- NS_params
str(calc_selectivity(params))
calc_selectivity(params)["Pelagic", "Herring", ]

Run the code above in your browser using DataLab