| calibrate_to | R Documentation |
Internal implementation shared by calibrateBiomass() and
calibrateNumber(). Rescales the model with scaleModel() so that the
total over all observed species of the modelled quantity agrees with the
total of the observations. Species with no observation are left out of both
totals.
calibrate_to(params, to = c("biomass", "number"))
params |
A MizerParams object. |
to |
The type of observation, either "biomass" or "number". |
A MizerParams object. If no non-missing observations are provided, the original object is returned unchanged.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.