| check_band_vars | R Documentation |
Check that a data frame has the variables a band style needs
check_band_vars(var_names, style)
var_names |
The names of the variables in the data frame. |
style |
The style that was requested. |
Nothing; called for the error.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.