Learn R Programming

mizer (version 3.4.0)

check_band_vars: Check that a data frame has the variables a band style needs

Description

Check that a data frame has the variables a band style needs

Usage

check_band_vars(var_names, style)

Value

Nothing; called for the error.

Arguments

var_names

The names of the variables in the data frame.

style

The style that was requested.