View source: R/ArraySpeciesBySize-class.R
| check_per_log_size | R Documentation |
per_log_size applies to a mizer arrayExpressing values per logarithmic size only means anything for a density,
so asking for it on anything else is an argument error rather than something
to be quietly ignored — which is what ... used to do with it.
check_per_log_size(x, per_log_size)
x |
A mizer array object. |
per_log_size |
The |
per_log_size, invisibly, if it applies.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.