per_log_size applies to a mizer arrayExpressing values per logarithmic size only means anything for a density,
so asking for it on anything else is an argument error rather than something
to be quietly ignored — which is what ... used to do with it.
check_per_log_size(x, per_log_size)per_log_size, invisibly, if it applies.
A mizer array object.
The per_log_size argument of the plot method.