View source: R/registerExtensions.R
| coerceToExtensionClass | R Documentation |
Coerces a MizerParams or MizerSim object to the S4 marker class
corresponding to the object's own extension chain. For MizerSim, the
extension chain is read from sim@params@extensions.
coerceToExtensionClass(object, extensions = objectExtensions(object))
object |
A |
extensions |
Optional extension chain. Defaults to the chain stored in
|
The same object coerced to the appropriate marker class, or to the base class for an empty extension chain.
"Creating a mizer extension package": Creating a mizer extension package
Other extension tools:
NOther(),
clearExtensionChain(),
getRegisteredExtensions(),
initialNOther<-(),
recordExtension(),
registerExtension(),
registerExtensions(),
setComponent(),
setRateFunction()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.