Coerces a MizerParams or MizerSim object to the S4 marker class
corresponding to the object's own extension chain. For MizerSim, the
extension chain is read from sim@params@extensions.
coerceToExtensionClass(object, extensions = objectExtensions(object))The same object coerced to the appropriate marker class, or to the base class for an empty extension chain.
A MizerParams or MizerSim object.
Optional extension chain. Defaults to the chain stored in
object, or in object@params for MizerSim.
"Creating a mizer extension package":
vignette("creating-extension-packages", package = "mizer")
Other extension tools:
NOther(),
clearExtensionChain(),
getRegisteredExtensions(),
initialNOther<-(),
registerExtension(),
registerExtensions(),
setComponent(),
setRateFunction()