Learn R Programming

mizer (version 3.4.0)

density_measure_jacobian: Jacobian converting between two density measures

Description

Jacobian converting between two density measures

Usage

density_measure_jacobian(from, to, w, l, b)

Value

A numeric vector by which to multiply a density with respect to from to obtain the density with respect to to.

Arguments

from, to

Density measures, see density_measures.

w, l, b

Numeric vectors of the same length giving the weight, the corresponding length, and the exponent of the weight-length relationship.