Jacobian converting between two density measures
density_measure_jacobian(from, to, w, l, b)A numeric vector by which to multiply a density with respect to
from to obtain the density with respect to to.
Density measures, see density_measures.
Numeric vectors of the same length giving the weight, the corresponding length, and the exponent of the weight-length relationship.