| density_measure_weight | R Documentation |
Writing N_w for the density with respect to weight, the density with
respect to measure m is N_w times the factor returned here. With
the allometric weight-length relationship w = a l^b these factors are
1 for "w", w for "log_w", dw/dl = b w / l for "l"
and l\,dw/dl = b w for "log_l".
density_measure_weight(measure, w, l, b)
measure |
One of density_measures. |
w, l, b |
Numeric vectors of the same length giving the weight, the corresponding length, and the exponent of the weight-length relationship. |
A numeric vector of factors.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.