Learn R Programming

mizer (version 3.4.0)

density_measure_weight: Factor relating a density measure to a density with respect to weight

Description

Writing \(N_w\) for the density with respect to weight, the density with respect to measure \(m\) is \(N_w\) times the factor returned here. With the allometric weight-length relationship \(w = a l^b\) these factors are \(1\) for "w", \(w\) for "log_w", \(dw/dl = b w / l\) for "l" and \(l\,dw/dl = b w\) for "log_l".

Usage

density_measure_weight(measure, w, l, b)

Value

A numeric vector of factors.

Arguments

measure

One of density_measures.

w, l, b

Numeric vectors of the same length giving the weight, the corresponding length, and the exponent of the weight-length relationship.