Learn R Programming

mizer (version 3.4.0)

dim_extents: Collect the extent of each labelled dimension

Description

Internal helper for sizeIntegral() that checks that arrays sharing a dimension label agree on its extent.

Usage

dim_extents(arrays, labels)

Value

A named integer vector giving the extent of each label.

Arguments

arrays

A list of arrays.

labels

A list of the corresponding label vectors.