This function expands the size grid in a MizerParams object to the desired min and max size, preserving all existing species.
expandSizeGrid(params, ...)# S3 method for MizerParams
expandSizeGrid(
params,
new_min_w = min(params@w),
new_max_w = max(params@w),
preserve_species = params@species_params$species,
...
)
A new MizerParams object with the updated size grid.
A MizerParams object.
Additional arguments (currently unused).
The new minimum size in the grid. Must not be larger than the current minimum size.
The new maximum size in the grid. Must not be smaller than the current maximum size.
A vector of species names for which all rate arrays should be copied over to the new params object rather than being re-calculated from the species parameters. If missing, all species are preserved.