Learn R Programming

mizer (version 3.4.0)

extension_needs_upgrading: Whether any extension recorded on an object needs upgrading

Description

Returns TRUE if, for any extension recorded on the object whose package is installed, the recorded version stamp is missing (NA) or older than the installed version of that package. A missing stamp counts as needing an upgrade so that objects created before extension-version tracking are brought up to date (and stamped) on first use; this is safe because runExtensionUpgrades() only calls an upgrade method if one is registered and such methods are written to be idempotent.

Usage

extension_needs_upgrading(params)

Value

TRUE or FALSE.

Arguments

params

A MizerParams object.