finalParams: Extract the final state from a simulation
Description
Returns the MizerParams object underlying the simulation with its initial
abundances set to the abundances at the last saved time step of the
simulation. This is a convenience wrapper around getParams() with no
time_range argument (the default).
Usage
finalParams(sim)
Value
A MizerParams object with initial values taken from the final time
step of the simulation.