View source: R/rate_functions.R
| flux_units | R Documentation |
getFlux()Units string for the flux returned by getFlux()
flux_units(power)
power |
The power of weight the flux was multiplied by. |
A character string with the units of the flux.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.