Learn R Programming

mizer (version 3.0.0)

flux_units: Units string for the flux returned by getFlux()

Description

Units string for the flux returned by getFlux()

Usage

flux_units(power)

Value

A character string with the units of the flux.

Arguments

power

The power of weight the flux was multiplied by.