| free_gear_name | R Documentation |
A gear name that the model is not already using
free_gear_name(params)
params |
A MizerParams object. |
A string naming a gear that does not exist in params.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.