Calculates the diffusion rate \(D_i(w)\) (grams^2/year) for each species. This is the rate at which the abundance density is diffused along the size axis due to the variability in prey sizes. This is the diffusion term from the jump-growth equation.
getDiffusion(object, ...)An array of dimensions species x size holding the diffusion rates.
A MizerParams or MizerSim object.
Additional arguments that depend on the class of object.
For a MizerParams object:
nA matrix of species abundances (species x size). Defaults to
the initial abundances stored in object.
n_ppA vector of the resource abundance by size. Defaults to the
initial resource abundance stored in object.
n_otherA named list of the abundances of other dynamical
components. Defaults to the initial values stored in object.
tThe time for which to do the calculation. Defaults to 0.
For a MizerSim object:
time_rangeThe time range over which to return the rates. Either a vector of values, a vector of min and max time, or a single value. Defaults to the whole time range of the simulation.
dropIf TRUE then any dimension of length 1 is removed from the
returned array.
Datta, S., Delius, G. W. and Law, R. (2010). A jump-growth model for predator-prey dynamics: derivation and application to marine ecosystems. Bulletin of Mathematical Biology, 72(6):1361–1382
Other rate functions:
getEGrowth(),
getERepro(),
getEReproAndGrowth(),
getEncounter(),
getFMort(),
getFMortGear(),
getFeedingLevel(),
getFlux(),
getMort(),
getPredMort(),
getPredRate(),
getRDD(),
getRDI(),
getRates(),
getResourceMort()