View source: R/rate_functions.R
| getFluxGradient | R Documentation |
Calculates the flux divergence
(J_{j+1} - J_j)/\Delta w_j that
appears as the second term in the discretised size-spectrum transport
equation
\frac{\partial N_j}{\partial t} + \frac{J_{j+1} - J_j}{\Delta w_j}
= -\mu_j N_j.
The bin-boundary fluxes J_j are obtained from getFlux(), which
uses the advective-flux scheme stored in the flux entry of the
second_order_w slot of params. The flux leaving
the largest size class through the upper boundary (J_{K+1}) is
evaluated with the same scheme using the boundary condition
N_{K+1} = 0.
getFluxGradient(object, ...)
object |
A MizerParams or MizerSim object. |
... |
Additional arguments that depend on the class of For a MizerParams object:
For a MizerSim object:
|
MizerParams: An ArraySpeciesBySize object (species x size) giving the
flux divergence in each size bin, in units of
g^{-1} \, \text{year}^{-1}.
MizerSim: An ArrayTimeBySpeciesBySize object (time step x species x
size) with the flux divergence at every saved time step. If drop = TRUE
then dimensions of length 1 will be removed.
getFlux(), second_order_w()
Other rate functions:
getDiffusion(),
getEGrowth(),
getERepro(),
getEReproAndGrowth(),
getEncounter(),
getFMort(),
getFMortGear(),
getFeedingLevel(),
getFlux(),
getMort(),
getPredMort(),
getPredRate(),
getRDD(),
getRDI(),
getRates(),
getResourceMort()
params <- NS_params
fg <- getFluxGradient(params)
sim <- project(params, t_max = 5)
fg_sim <- getFluxGradient(sim)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.