Learn R Programming

mizer (version 3.0.0)

getPhiPrey: Get available energy

Description

[Deprecated]

This is deprecated and is no longer used by the mizer project() method. Calculates the amount \(E_{a,i}(w)\) of food exposed to each predator as a function of predator size.

Usage

getPhiPrey(object, n, n_pp, ...)

Value

A two dimensional array (predator species x predator size) equal to getEncounter(object, n, n_pp) / getSearchVolume(object).

Arguments

object

An MizerParams object

n

A matrix of species abundances (species x size)

n_pp

A vector of the background abundance by size

...

Other arguments (currently unused)

See Also

project()