This is deprecated and is no longer used by the mizer project() method. Calculates the amount \(E_{a,i}(w)\) of food exposed to each predator as a function of predator size.
getPhiPrey(object, n, n_pp, ...)A two dimensional array (predator species x predator size)
equal to getEncounter(object, n, n_pp) / getSearchVolume(object).
An MizerParams object
A matrix of species abundances (species x size)
A vector of the background abundance by size
Other arguments (currently unused)
project()