View source: R/rate_functions.R
| getRDI | R Documentation |
Calculates the density-independent rate of total egg production
R_{di} (units 1/year) before density dependence, by species.
getRDI(object, ...)
object |
A MizerParams or MizerSim object. |
... |
Additional arguments that depend on the class of For a MizerParams object:
For a MizerSim object:
|
This rate is obtained by taking the per capita rate E_r(w)\psi(w) at
which energy is invested in reproduction, as calculated by getERepro(),
multiplying it by the number of individualsN(w) and integrating over
all sizes w and then multiplying by the reproductive efficiency
\epsilon and dividing by the egg size w_min, and by a factor of two
to account for the two sexes:
R_{di} = \frac{\epsilon}{2 w_{min}} \int N(w) E_r(w) \psi(w) \, dw
Used by getRDD() to calculate the actual, density dependent rate.
See setReproduction() for more details.
MizerParams: A numeric vector the length of the number of species.
MizerSim: An ArrayTimeBySpecies object (time x species).
By default getRDI() calls mizerRDI(). However you can
replace this with your own alternative reproduction function. If
your function is called "myRDI" then you register it in a MizerParams
object params with
params <- setRateFunction(params, "RDI", "myRDI")
Your function will then be called instead of mizerRDI(), with the
same arguments. For an example of an alternative reproduction function
see constantEggRDI().
getRDD()
Other rate functions:
getDiffusion(),
getEGrowth(),
getERepro(),
getEReproAndGrowth(),
getEncounter(),
getFMort(),
getFMortGear(),
getFeedingLevel(),
getFlux(),
getFluxGradient(),
getMort(),
getPredMort(),
getPredRate(),
getRDD(),
getRates(),
getResourceMort()
params <- NS_params
# Project with constant fishing effort for all gears for 20 time steps
sim <- project(params, t_max = 20, effort = 0.5)
# Get the density-independent reproduction rate at a particular time step
getRDI(params, n = N(sim)[15, , ], n_pp = NResource(sim)[15, ], t = 15)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.