Learn R Programming

mizer (version 3.0.0)

getSSB: Calculate the SSB of species

Description

Calculates the spawning stock biomass (SSB) for each species. For a MizerSim object this is returned for every saved time; for a MizerParams object it is calculated from the initial state. SSB is the total mass of all mature individuals.

Usage

getSSB(object)

Value

If called with a MizerParams object, a named vector with the SSB in grams for each species in the model. If called with a MizerSim object, a ArrayTimeBySpecies object (time x species) containing the SSB in grams at each time step for all species.

Arguments

object

An object of class MizerParams or MizerSim.

See Also

Other summary functions: getBiomass(), getDiet(), getGrowthCurves(), getN(), getTrophicLevel(), getTrophicLevelBySpecies(), getYield(), getYieldGear()

Examples

Run this code
ssb <- getSSB(NS_sim)
ssb[c("1972", "2010"), c("Herring", "Cod")]

Run the code above in your browser using DataLab