Calculates the spawning stock biomass (SSB) for each species. For a
MizerSim object this is returned for every saved time; for a
MizerParams object it is calculated from the initial state. SSB is the
total mass of all mature individuals.
Usage
getSSB(object)
Value
If called with a MizerParams object, a named vector with the SSB in
grams for each species in the model. If called with a MizerSim object, a
ArrayTimeBySpecies object (time x species) containing the SSB in grams
at each time step for all species.