Learn R Programming

mizer (version 3.0.0)

getSimParams: Extract the projection parameters used to produce a simulation

Description

Returns the named list of arguments passed to project() or projectToSteady() when producing this MizerSim object, such as method and dt. Returns an empty list for simulations produced by older versions of mizer.

Usage

getSimParams(sim)

Value

A named list of projection parameters.

Arguments

sim

A MizerSim object

Examples

Run this code
sim <- project(NS_params, t_max = 0.1, dt = 0.05, method = "predictor-corrector")
getSimParams(sim)

Run the code above in your browser using DataLab