getSimParams: Extract the projection parameters used to produce a simulation
Description
Returns the named list of arguments passed to project() or
projectToSteady() when producing this MizerSim object, such as
method and dt. Returns an empty list for simulations produced by
older versions of mizer.