Learn R Programming

mizer (version 3.0.0)

getTrophicLevelBySpecies: Get mean trophic level of each species

Description

[Experimental] Calculates the consumption-rate-weighted mean trophic level of each species, defined as $$ T_i = \frac{\int r_i(w)\,N_i(w)\,T_i(w)\,dw} {\int r_i(w)\,N_i(w)\,dw}, $$ where \(r_i(w) = (1 - f_i(w))\,E_i(w)\) is the consumption rate of an individual of species \(i\) at weight \(w\), \(N_i(w)\) is the abundance density, and \(T_i(w)\) is the size-resolved trophic level from getTrophicLevel().

Usage

getTrophicLevelBySpecies(
  params,
  n = initialN(params),
  n_pp = initialNResource(params),
  n_other = initialNOther(params),
  ...
)

Value

A named vector with the mean trophic level for each species.

Arguments

params

A MizerParams object.

n

A matrix of species abundances (species x size). Defaults to the initial abundances stored in params.

n_pp

A vector of the resource abundance by size. Defaults to the initial resource abundance stored in params.

n_other

A named list of the abundances of other dynamical components. Defaults to the initial values stored in params.

...

Unused

See Also

getTrophicLevel()

Other summary functions: getBiomass(), getDiet(), getGrowthCurves(), getN(), getSSB(), getTrophicLevel(), getYield(), getYieldGear()

Examples

Run this code
getTrophicLevelBySpecies(NS_params)

Run the code above in your browser using DataLab