get_ArrayResourceBySize_w: Get the size grid for an ArrayResourceBySize object
Description
Internal helper that returns the full prey/resource size grid
params@w_full, or the numeric vector parsed from the names of x if no
params is attached.
Usage
get_ArrayResourceBySize_w(x)
Value
A numeric vector giving the size represented by each element.
Arguments
- x
An ArrayResourceBySize object.