get_ArraySpeciesBySize_w: Get the size grid for an ArraySpeciesBySize object
Description
Internal helper that returns the consumer size grid params@w or the full
prey/resource size grid params@w_full, depending on the number of columns
in the array.
Usage
get_ArraySpeciesBySize_w(x)
Value
A numeric vector giving the size represented by each column.
Arguments
- x
An ArraySpeciesBySize object.