Fills in any missing values for gamma so that fish feeding on a resource spectrum described by the power law \(\kappa w^{-\lambda}\) achieve a feeding level \(f_0\). Only for internal use.
get_gamma_default(params)A vector with the values of gamma for all species
A MizerParams object
See the Search Volume Coefficient section of the "Calculation of Default Parameter Values" vignette for the mathematical derivation.
Other functions calculating defaults:
get_f0_default(),
get_h_default(),
get_ks_default()