| get_species_time_rate_from_sim | R Documentation |
Internal helper used by MizerSim rate methods whose one-time result is a
named vector with one value for each species.
get_species_time_rate_from_sim(
sim,
time_range,
rate_fun,
value_name,
units = NULL
)
sim |
A |
time_range |
A numeric or character vector of times. |
rate_fun |
A function accepting a single simulation slice as returned by
|
value_name |
Name of the value stored in the returned array. |
units |
Optional units of the value stored in the returned array. |
An ArrayTimeBySpecies object with dimensions time x species.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.