Internal helper used by MizerSim rate methods whose one-time result is a
named vector with one value for each species.
get_species_time_rate_from_sim(
sim,
time_range,
rate_fun,
value_name,
units = NULL
)An ArrayTimeBySpecies object with dimensions time x species.
A MizerSim object.
A numeric or character vector of times.
A function accepting a single simulation slice as returned by
get_sim_rate_slice().
Name of the value stored in the returned array.
Optional units of the value stored in the returned array.