powered by
Returns the MizerParams object underlying the simulation with its initial abundances set to the abundances at the initial time of the simulation.
MizerParams
initialParams(sim)
A MizerParams object with initial state of the simulation.
A MizerSim object.
MizerSim
getParams(), finalParams()
getParams()
finalParams()
sim <- project(NS_params, t_max = 20, effort = 0.5) params_start <- initialParams(sim)
Run the code above in your browser using DataLab