isSteady: Check whether a model is at steady state

View source: R/getSteadyResidual.R

isSteadyR Documentation

Check whether a model is at steady state

Description

[Experimental] Returns TRUE if the model is at its steady state (within a specified tolerance), FALSE otherwise.

Usage

isSteady(params, tol = 0.05, effort = params@initial_effort, ...)

Arguments

params

A MizerParams object or an extension thereof.

tol

Tolerance for the relative rate of biomass change in 1/year. Defaults to 0.05 (5% change per year).

effort

The fishing effort at which to evaluate steadiness. By default the initial effort stored in params.

...

Additional arguments passed to methods.

Details

Steadiness is judged by computing the relative rate of change of biomass across all consumer species, resource, and other components (see getSteadyResidual()). If the largest biomass drift is less than or equal to tol, the model is considered to be at steady state.

Value

TRUE if the model's biomass drift is within tol, FALSE otherwise.

See Also

getSteadyResidual(), tuneSteadyState(), findSteadyState()

Examples

isSteady(NS_params)


# Moving a species abundance off its steady state makes isSteady() FALSE
params <- NS_params
initialN(params)[1, ] <- initialN(params)[1, ] * 2
isSteady(params)


mizer documentation built on Aug. 24, 2026, 9:08 a.m.