View source: R/getSteadyResidual.R
| isSteady | R Documentation |
Returns
TRUE if the model is at its steady state (within a specified
tolerance), FALSE otherwise.
isSteady(params, tol = 0.05, effort = params@initial_effort, ...)
params |
A MizerParams object or an extension thereof. |
tol |
Tolerance for the relative rate of biomass change in 1/year.
Defaults to |
effort |
The fishing effort at which to evaluate steadiness. By default
the initial effort stored in |
... |
Additional arguments passed to methods. |
Steadiness is judged by computing the relative rate of change of biomass
across all consumer species, resource, and other components (see
getSteadyResidual()). If the largest biomass drift is less than or equal to
tol, the model is considered to be at steady state.
TRUE if the model's biomass drift is within tol, FALSE
otherwise.
getSteadyResidual(), tuneSteadyState(), findSteadyState()
isSteady(NS_params)
# Moving a species abundance off its steady state makes isSteady() FALSE
params <- NS_params
initialN(params)[1, ] <- initialN(params)[1, ] * 2
isSteady(params)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.