Learn R Programming

mizer (version 3.0.0)

isSuffixChain: Test whether one extension chain is a suffix of another

Description

An empty candidate is always a suffix. Order and values must match exactly for the overlapping tail.

Usage

isSuffixChain(candidate, chain)

Value

TRUE if candidate is a suffix of chain, FALSE otherwise.

Arguments

candidate

Named character vector to test.

chain

Named character vector that may contain candidate as a tail.