knife_edge: Weight based knife-edge selectivity function
Description
A knife-edge selectivity function where weights greater or equal to
knife_edge_size are fully selected and no fish smaller than this size
are selected.
Usage
knife_edge(w, knife_edge_size, ...)
Value
Vector of selectivities at the given sizes.
Arguments
w
Vector of sizes.
knife_edge_size
The weight at which the knife-edge operates.
...
Unused
Details
You would not usually call this function directly. Instead, set the sel_func
column in gear_params() to "knife_edge" and provide knife_edge_size as
an additional column. setFishing() will then call this function
automatically when calculating the selectivity array.
See Also
gear_params() for setting the knife_edge_size parameter.
Other selectivity functions:
double_sigmoid_length(),
sigmoid_length(),
sigmoid_weight()