| make_linesize | R Documentation |
Helper used by the plotting functions to give highlighted species a thicker line than the rest.
make_linesize(levels, highlight)
levels |
Character vector of the legend levels (usually species names). |
highlight |
Name or vector of names of the levels to be highlighted with a thicker line. |
A named numeric vector of line widths, one for each entry in
levels, with highlighted entries set to a larger value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.