Helper used by the plotting functions to give highlighted species a thicker line than the rest.
make_linesize(levels, highlight)A named numeric vector of line widths, one for each entry in
levels, with highlighted entries set to a larger value.
Character vector of the legend levels (usually species names).
Name or vector of names of the levels to be highlighted with a thicker line.