| make_mizer_plot | R Documentation |
Attaches the tooltip information to a ggplot object and adds the
"mizer_plot" class so that plotHover() knows which aesthetics to show.
make_mizer_plot(plot, tooltip)
plot |
A ggplot object. |
tooltip |
Character vector of variable names to include in the plotly tooltip. |
The plot object with the tooltip stored as an attribute and
"mizer_plot" prepended to its class.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.