| measure_on_attractor | R Documentation |
Measure a quantity on the attractor a projection settled on
measure_on_attractor(
settled,
value_func,
conv,
dt,
t_sample,
sample_all,
method,
default_name = "Value"
)
settled |
The MizerParams returned by |
value_func |
The function measuring the quantity. |
conv |
The |
dt |
The time step. |
t_sample |
The averaging window to use when nothing settled. |
sample_all |
Whether to sample even at a fixed point. |
method |
The numerical method. |
default_name |
The series name to use when |
A list with the mean, minimum and maximum over the attractor, the
names of the series and the metadata read off value_func's result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.