Measure a quantity on the attractor a projection settled on
measure_on_attractor(
settled,
value_func,
conv,
dt,
t_sample,
sample_all,
method,
default_name = "Value"
)A list with the mean, minimum and maximum over the attractor, the
names of the series and the metadata read off value_func's result.
The MizerParams returned by project_until_settled().
The function measuring the quantity.
The "convergence" attribute of settled.
The time step.
The averaging window to use when nothing settled.
Whether to sample even at a fixed point.
The numerical method.
The series name to use when value_func supplies none.