Calculates the diffusion rate \(D_i(w)\) (grams^2/year) for each species. This diffusion rate has two components:
The diffusion due due to the variability in prey sizes. This is the diffusion term from the jump-growth equation.
Any externally specified diffusion, which is added via setExtDiffusion()
You would not usually call this function directly but instead use
getDiffusion(), which then calls this function unless an alternative
diffusion rate function has been registered, see setRateFunction().
projectDiffusion(params, n, n_pp, n_other, t = 0, feeding_level, ...)# S3 method for MizerParams
projectDiffusion(params, n, n_pp, n_other, t = 0, feeding_level, ...)
mizerDiffusion(params, n, n_pp, n_other, t = 0, feeding_level, ...)
A two dimensional array (species x size) holding the diffusion rate.
A MizerParams object
A matrix of species abundances (species x size).
A vector of the resource abundance by size
A list of abundances for other dynamical components
The time for which to do the calculation (Not used by standard mizer rate functions but useful for extensions.)
An array (species x size) with the feeding level. If not provided, it is calculated from the given abundances.
Unused