| mizer_tooltip_vars | R Documentation |
Works out which variables should appear in the plotly tooltip, including the legend variable only when it differs from the grouping variable, plus any extra variables.
mizer_tooltip_vars(
frame,
group_var,
x_var,
y_var,
legend_var = NULL,
extra = NULL
)
frame |
The data frame underlying the plot. |
group_var |
Name of the grouping variable. |
x_var |
Name of the variable on the x-axis. |
y_var |
Name of the variable on the y-axis. |
legend_var |
Optional name of the legend variable. |
extra |
Optional character vector of additional variable names to include. |
A character vector of variable names for the tooltip.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.