Works out which variables should appear in the plotly tooltip, including the legend variable only when it differs from the grouping variable, plus any extra variables.
mizer_tooltip_vars(
frame,
group_var,
x_var,
y_var,
legend_var = NULL,
extra = NULL
)A character vector of variable names for the tooltip.
The data frame underlying the plot.
Name of the grouping variable.
Name of the variable on the x-axis.
Name of the variable on the y-axis.
Optional name of the legend variable.
Optional character vector of additional variable names to include.