Learn R Programming

mizer (version 3.0.0)

needed_rates: Determine which rates must be calculated to obtain a set of target rates

Description

Internal helper returning the transitive closure of targets over .rate_dependencies, in an order in which the rates can be calculated (each rate appears after all the rates it depends on).

Usage

needed_rates(targets)

Value

A character vector of rate names.

Arguments

targets

Character vector of rate names (as in params@rates_funcs).