| observation_columns | R Documentation |
Internal helper for the calibration and matching functions. Observations of
type to live in the <to>_observed column of the species parameters,
alongside an optional <to>_cutoff column giving the smallest size that the
observation includes.
observation_columns(to = c("biomass", "number"))
to |
The type of observation, either "biomass" or "number". |
A list with entries to, observed and cutoff, the latter two
giving the names of the corresponding species parameter columns.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.