Internal helper for the calibration and matching functions. Observations of
type to live in the <to>_observed column of the species parameters,
alongside an optional <to>_cutoff column giving the smallest size that the
observation includes.
observation_columns(to = c("biomass", "number"))A list with entries to, observed and cutoff, the latter two
giving the names of the corresponding species parameter columns.
The type of observation, either "biomass" or "number".