log argument for time-series plotsTranslates the log argument of the time-series plotting functions into a
list of logical flags for the x and y axes, falling back to log_x and
log_y when log is NULL. For backwards compatibility a single logical
log value sets only log_y.
parseTimePlotLog(log, log_x, log_y)A list with logical elements log_x and log_y.
NULL, a single logical value, or a character string containing
only "x" and/or "y".
Default logical flags used when log is NULL.