View source: R/ArrayResourceBySize-class.R
| plot.ArrayResourceBySize | R Documentation |
ArrayResourceBySize objectsSee plot() for an overview of the mizer plotting system and the
arguments shared by all of its methods.
## S3 method for class 'ArrayResourceBySize'
plot(
x,
return_data = FALSE,
log_x = TRUE,
log_y = TRUE,
log = NULL,
wlim = c(NA, NA),
llim = c(NA, NA),
ylim = c(NA, NA),
size_axis = c("w", "l"),
per_log_size = NULL,
y_ticks = 6,
...
)
x |
An |
return_data |
If |
log_x |
If |
log_y |
If |
log |
Character string specifying which axes should use log10
scales, in the same form as the base |
wlim |
A numeric vector of length two providing lower and upper
limits for the weight (x) axis. Use |
llim |
A numeric vector of length two providing lower and upper limits
for the length (x) axis when |
ylim |
A numeric vector of length two providing lower and upper
limits for the value (y) axis. Use |
size_axis |
Whether to plot size as weight ( |
per_log_size |
For an array that holds a density, whether to plot it
per logarithmic size ( |
y_ticks |
The approximate number of ticks desired on the y axis. |
... |
Unused. |
A ggplot2 object, unless return_data = TRUE, in which case a
data frame is returned.
plot(getResourceMort(NS_params))
plot(initialNResource(NS_params))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.