A ggplot2 object, unless return_data = TRUE, in which case a
data frame is returned.
Arguments
x
An ArrayResourceBySize object.
return_data
If TRUE, return the data frame instead of the
plot.
log_x
If TRUE, use a log10 x-axis. Default is TRUE.
log_y
If TRUE, use a log10 y-axis. Default is TRUE.
log
Character string specifying which axes should use log10
scales, in the same form as the base plot() argument. For example,
"x", "y", "xy" or "". If supplied, this overrides log_x and
log_y.
wlim
A numeric vector of length two providing lower and upper
limits for the weight (x) axis. Use NA to refer to the existing
minimum or maximum.
ylim
A numeric vector of length two providing lower and upper
limits for the value (y) axis. Use NA to refer to the existing
minimum or maximum.
y_ticks
The approximate number of ticks desired on the y axis.