View source: R/ArraySpeciesBySize-class.R
| plot.ArraySpeciesBySize | R Documentation |
ArraySpeciesBySize objectsSee plot() for an overview of the mizer plotting system and the
arguments shared by all of its methods.
## S3 method for class 'ArraySpeciesBySize'
plot(
x,
species = NULL,
all.sizes = FALSE,
highlight = NULL,
return_data = FALSE,
log_x = TRUE,
log_y = FALSE,
log = NULL,
wlim = c(NA, NA),
llim = c(NA, NA),
ylim = c(NA, NA),
size_axis = c("w", "l"),
per_log_size = NULL,
total = FALSE,
background = TRUE,
y_ticks = 6,
...
)
x |
An |
species |
Character vector of species to include. |
all.sizes |
If |
highlight |
Name or vector of names of the species to be highlighted. |
return_data |
If |
log_x |
If |
log_y |
If |
log |
Character string specifying which axes should use log10
scales, in the same form as the base |
wlim |
A numeric vector of length two providing lower and upper
limits for the weight (x) axis. Use |
llim |
A numeric vector of length two providing lower and upper
limits for the length (x) axis when |
ylim |
A numeric vector of length two providing lower and upper
limits for the value (y) axis. Use |
size_axis |
Whether to plot size as weight ( |
per_log_size |
For an array that holds a density, whether to plot it per
logarithmic size ( |
total |
A boolean value that determines whether the total is plotted
as well. The total is the total of everything the array holds, every
species and every size, whatever is drawn. Default is |
background |
A boolean value that determines whether background
species are included. Ignored if the model does not contain background
species. Default is |
y_ticks |
The approximate number of ticks desired on the y axis. |
... |
Unused. |
A ggplot2 object, unless return_data = TRUE, in which case a
data frame is returned.
plot(getEncounter(NS_params))
plot(getFeedingLevel(NS_params), species = c("Cod", "Herring"))
plot(getPredMort(NS_params), species = c("Cod", "Herring"),
size_axis = "l")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.