Learn R Programming

mizer (version 3.2.0)

plot.ArrayTimeByResourceBySize: Plot method for ArrayTimeByResourceBySize objects

Description

See plot() for an overview of the mizer plotting system. This method plots a single time slice, by first extracting it as an ArrayResourceBySize object and delegating to plot.ArrayResourceBySize(), which the further arguments in ... are passed on to.

Usage

# S3 method for ArrayTimeByResourceBySize
plot(x, time = NULL, ...)

Value

A ggplot2 object, unless return_data = TRUE, in which case a data frame is returned.

Arguments

x

An ArrayTimeByResourceBySize object.

time

The time to display. Default (NULL) is the final time step.

...

Passed on to plot.ArrayResourceBySize().

Examples

Run this code
# \donttest{
plot(NResource(NS_sim))
# }

Run the code above in your browser using DataLab