Used internally by the comparison plotting functions such as plotSpectra2()
and plotCDF2(). The two data frames are combined and drawn with colour
identifying the species or group and linetype identifying the object.
plotComparisonDataFrame(
frame1,
frame2,
params,
name1 = "First",
name2 = "Second",
xlab = waiver(),
ylab = waiver(),
xtrans = "identity",
ytrans = "identity",
xlim = c(NA, NA),
ylim = c(NA, NA),
y_ticks = 6,
highlight = NULL,
legend_var = "Legend",
size_axis = NULL
)A mizer_plot (ggplot2) object.
Data frames sharing the same first three variables (x, y
and grouping variable). The names of frame1 are imposed on frame2.
A MizerParams object, used for the line colours.
Labels for the two data frames, used in the linetype legend.
Labels for the x and y axes.
Transformations for the x and y axes, e.g. "log10" or
"identity".
Numeric vectors of length two giving the axis limits. Use
NA to refer to the existing minimum or maximum.
The approximate number of ticks desired on the y axis.
Name or vector of names of the species to be highlighted.
Name of the variable used in the legend and to determine the line colour.
Optional. If non-NULL, the x-axis is converted to weight
("w") or length ("l").