Learn R Programming

mizer (version 2.1.0)

plotDiet: Plot diet

Description

[Experimental]

Usage

plotDiet(object, species = NULL)

Arguments

object

An object of class '>MizerSim or '>MizerParams.

species

The species to be selected. Optional. By default all target species are selected. A vector of species names, or a numeric vector with the species indices, or a logical vector indicating for each species whether it is to be selected (TRUE) or not.

Value

A ggplot2 object

See Also

Other plotting functions: plot,MizerSim,missing-method, plotBiomass(), plotFMort(), plotFeedingLevel(), plotGrowthCurves(), plotPredMort(), plotSpectra(), plotYieldGear(), plotYield(), plotting_functions