Learn R Programming

mizer (version 3.0.0)

plotMizerParams: Summary plot for MizerParams objects

Description

Produces 3 plots in the same window: abundance spectra, feeding level and predation mortality of each species against size. This method just puts the plots generated by plotFeedingLevel(), plotPredMort() and plotSpectra() all in one window.

Usage

# S3 method for MizerParams
plot(x, ...)

Value

A viewport object

Arguments

x

An object of class MizerParams

...

Arguments passed on to the individual plotting functions plotFeedingLevel(),plotSpectra(),plotPredMort()

See Also

plotting_functions

Other plotting functions: addPlot(), animate.ArrayTimeBySpeciesBySize(), plot, plot2(), plotBiomass(), plotCDF(), plotCDF2(), plotDiet(), plotFMort(), plotFeedingLevel(), plotGrowthCurves(), plotMizerSim, plotPredMort(), plotRelative(), plotSpectra(), plotSpectra2(), plotSpectraRelative(), plotYield(), plotYieldGear(), plotting_functions

Examples

Run this code
# \donttest{
params <-  NS_params
plot(params)
# }

Run the code above in your browser using DataLab