Learn R Programming

mizer (version 3.0.0)

plotMizerSim: Summary plot for MizerSim objects

Description

After running a projection, produces 5 plots in the same window: feeding level, abundance spectra, predation mortality and fishing mortality of each species by size; and biomass of each species through time. This method just puts the plots generated by plotBiomass(), plotFeedingLevel(), plotSpectra(), plotPredMort() and plotFMort() all in one window.

Usage

# S3 method for MizerSim
plot(x, ...)

Value

A viewport object

Arguments

x

An object of class MizerSim

...

Arguments passed on to the individual plotting functions plotBiomass(), plotFeedingLevel(), plotSpectra(), plotPredMort() and plotFMort().

See Also

plotting_functions

Other plotting functions: addPlot(), animate.ArrayTimeBySpeciesBySize(), plot, plot2(), plotBiomass(), plotCDF(), plotCDF2(), plotDiet(), plotFMort(), plotFeedingLevel(), plotGrowthCurves(), plotMizerParams, plotPredMort(), plotRelative(), plotSpectra(), plotSpectra2(), plotSpectraRelative(), plotYield(), plotYieldGear(), plotting_functions

Examples

Run this code
# \donttest{
params <-  NS_params
sim <- project(params, effort=1, t_max=20, t_save = 2, progress_bar = FALSE)
plot(sim)
# }

Run the code above in your browser using DataLab