Internal worker shared by the plotGrowthCurves() methods. It computes the
modelled size at age, optionally adds a von Bertalanffy curve and observed
size-at-age data, and draws the plot.
plot_growth_curves(
params,
species,
max_age,
percentage,
species_panel,
highlight,
log_x,
log_y,
size_at_age,
return_data
)A mizer_plot (ggplot2) object, or the plotting data frame if
return_data = TRUE.
A MizerParams object.
The species to be plotted.
The age up to which to plot the growth curve.
If TRUE, size is shown as a percentage of maximum size.
If TRUE, each species is shown in its own panel.
Name or vector of names of species to be highlighted.
Logical flags for log10 axes.
Optional data frame of observed size-at-age data.
If TRUE, return the plotting data frame instead of the
plot.