Learn R Programming

mizer (version 3.0.0)

plot_size_tooltip: Assemble the tooltip variables for a size-axis plot

Description

Assemble the tooltip variables for a size-axis plot

Usage

plot_size_tooltip(size_axis, before = NULL, after = NULL)

Value

A character vector of tooltip variable names.

Arguments

size_axis

Either "w" (weight) or "l" (length).

before, after

Optional character vectors of variable names to place before and after the size variable in the tooltip.