| plot_size_xlim | R Documentation |
Choose the x-axis limits for a given size axis
plot_size_xlim(wlim, size_axis, llim = c(NA, NA))
wlim |
Numeric vector of length two giving the weight limits. |
size_axis |
Either |
llim |
Numeric vector of length two giving the length limits. |
llim for a length axis, otherwise wlim.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.