Learn R Programming

mizer (version 3.0.0)

plot_size_xlim: Choose the x-axis limits for a given size axis

Description

Choose the x-axis limits for a given size axis

Usage

plot_size_xlim(wlim, size_axis, llim = c(NA, NA))

Value

llim for a length axis, otherwise wlim.

Arguments

wlim

Numeric vector of length two giving the weight limits.

size_axis

Either "w" (weight) or "l" (length).

llim

Numeric vector of length two giving the length limits.