| plot_y_is_log | R Documentation |
Read from the plot's own y scale, so that data being added to an existing plot can be filtered the way that plot was. A plot with no explicit y scale has ggplot2's default, which is linear.
plot_y_is_log(plot)
plot |
A ggplot2 object. |
TRUE if the plot's y axis uses a log10 transformation.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.