plot_y_is_log: Whether a plot's y axis is logarithmic
Description
Read from the plot's own y scale, so that data being added to an existing
plot can be filtered the way that plot was. A plot with no explicit y scale
has ggplot2's default, which is linear.
Usage
plot_y_is_log(plot)
Value
TRUE if the plot's y axis uses a log10 transformation.