Learn R Programming

mizer (version 3.4.0)

prepare_MizerScan_plot_data: Prepare the data frame for plotting a MizerScan

Description

Prepare the data frame for plotting a MizerScan

Usage

prepare_MizerScan_plot_data(x, species = NULL)

Value

A data frame with the x, y and grouping variable in the first three columns, as plotDataFrame() requires.

Arguments

x

A MizerScan object.

species

The series to keep, or NULL for all of them.