| prepare_spectra_cdf_data | R Documentation |
Multiplies the spectra density by the size-bin widths and forms the cumulative sum over size for each species, optionally normalising each curve to end at 1.
prepare_spectra_cdf_data(plot_dat, params, normalise = TRUE)
plot_dat |
Spectra plotting data with a |
params |
A MizerParams object, used for the size-bin widths. |
normalise |
If |
The plotting data with the value column replaced by its cumulative distribution over size.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.