Multiplies the spectra density by the size-bin widths and forms the cumulative sum over size for each species, optionally normalising each curve to end at 1.
prepare_spectra_cdf_data(plot_dat, params, normalise = TRUE)The plotting data with the value column replaced by its cumulative distribution over size.
Spectra plotting data with a w column, a Species column
and the value in the second column.
A MizerParams object, used for the size-bin widths.
If TRUE (default), divide each species' curve by its
maximum.