Learn R Programming

mizer (version 3.0.0)

print: Print mizer objects

Description

Mizer supplies print() methods for the array-like objects returned by many rate and summary functions. These methods print a compact, readable overview instead of the full matrix or array. The printed output reports the value name, dimensions, units if known, and per-species minimum, mean and maximum values.

Value

The printed object, invisibly.

Arguments

x

The object to print.

...

Further arguments. They are currently ignored by the mizer methods.

Details

For full numeric access, use the object itself as an ordinary matrix or array or convert it to a long data frame with as.data.frame().

See Also

summary(), as.data.frame(), plot(), ArraySpeciesBySize(), ArrayTimeBySpecies(), ArrayTimeBySpeciesBySize()

Examples

Run this code
# \donttest{
enc <- getEncounter(NS_params)
print(enc)

biomass <- getBiomass(NS_sim)
print(biomass)
# }

Run the code above in your browser using DataLab