Learn R Programming

mizer (version 3.4.0)

print.mizer_plot: Print a mizer plot

Description

Suppresses the uninformative ggplot2 warning about log transformations introducing infinite values, which occurs when zero values are present on a logged axis.

Usage

# S3 method for mizer_plot
print(x, ...)

Value

The plot object, invisibly.

Arguments

x

A mizer_plot object.

...

Further arguments passed to the ggplot2 print method.