Sets the reproductive efficiency for all species so that the rate of egg
production exactly compensates for the loss from the first size class due
to growth and mortality. Turns off the external density dependence in the
reproduction rate by setting the RDD function to
noRDD()
retune_erepro(params, species = species_params(params)$species)The species to be selected. Optional. By default all target species are selected. A vector of species names, or a numeric vector with the species indices, or a logical vector indicating for each species whether it is to be selected (TRUE) or not.
A MizerParams object with updated values for the erepro column
in the species_params data frame.