View source: R/MizerScan-class.R
| scan_plot_params | R Documentation |
Series that are not species have no colour in the model, and
plotDataFrame() silently drops any legend level it cannot find a colour
for. So any such series is given a colour here, using the ordinary
setColours() interface, which also leaves the user free to choose a
different one.
scan_plot_params(x, plot_dat)
x |
A MizerScan object. |
plot_dat |
The data frame that will be plotted. |
A MizerParams object with a colour for every series in plot_dat.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.