Series that are not species have no colour in the model, and
plotDataFrame() silently drops any legend level it cannot find a colour
for. So any such series is given a colour here, using the ordinary
setColours() interface, which also leaves the user free to choose a
different one.
scan_plot_params(x, plot_dat)A MizerParams object with a colour for every series in plot_dat.
A MizerScan object.
The data frame that will be plotted.