| select_gear_rows | R Documentation |
The gear params rows whose fishing mortality is to be varied
select_gear_rows(gp, species, gear = NULL)
gp |
The gear params data frame, with a character |
species |
The target species. |
gear |
The selected gear, or NULL for all gears catching the species. |
An integer vector of row indices.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.