Learn R Programming

mizer (version 3.4.0)

select_gear_rows: The gear params rows whose fishing mortality is to be varied

Description

The gear params rows whose fishing mortality is to be varied

Usage

select_gear_rows(gp, species, gear = NULL)

Value

An integer vector of row indices.

Arguments

gp

The gear params data frame, with a character gear column.

species

The target species.

gear

The selected gear, or NULL for all gears catching the species.