Learn R Programming

mizer (version 3.0.0)

sigmoid_length: Length based sigmoid selectivity function

Description

A sigmoid shaped selectivity function. Based on two parameters l25 and l50 which determine the length at which 25% and 50% of the stock is selected respectively.

Usage

sigmoid_length(w, l25, l50, species_params, ...)

Value

Vector of selectivities at the given sizes.

Arguments

w

Vector of sizes.

l25

the length which gives a selectivity of 25%.

l50

the length which gives a selectivity of 50%.

species_params

A list with the species params for the current species. Used to get at the length-weight parameters a and b.

...

Unused

Details

You would not usually call this function directly. Instead, set the sel_func column in gear_params() to "sigmoid_length" and provide the l25 and l50 values as additional columns. setFishing() will then call this function automatically when calculating the selectivity array.

The selectivity is given by the logistic function $$S(l) = \frac{1}{1 + \exp\left(\log(3)\frac{l50 -l}{l50 - l25}\right)}$$ As the mizer model is weight based, and this selectivity function is length based, it uses the length-weight parameters a and b to convert between length and weight $$l = \left(\frac{w}{a}\right)^{1/b}$$

See Also

gear_params() for setting the selectivity parameters.

Other selectivity functions: double_sigmoid_length(), knife_edge(), sigmoid_weight()

Examples

Run this code
# Selectivity at weight given l25 = 10 cm, l50 = 15 cm
# using length-weight parameters a = 0.01, b = 3
sp <- list(a = 0.01, b = 3)
w <- c(1, 10, 100, 500, 1000)
sigmoid_length(w, l25 = 10, l50 = 15, species_params = sp)

Run the code above in your browser using DataLab