| sim_species_rate | R Documentation |
MizerSim rate getter that resolves the rate functions onceLike sim_size_rate() but for getters that return one value per species at
each time step (a time-by-species array), such as getRDI() and getRDD().
By default these use the initial effort, matching their MizerParams counterparts.
sim_species_rate(
sim,
time_range,
target,
slot,
value_name,
units = NULL,
use_sim_effort = FALSE,
...
)
sim |
A |
time_range |
Passed to the sim iteration helper. |
target |
Name of the rate to calculate (as in |
slot |
Name of the element to extract from the |
value_name, units |
Metadata for the returned array. |
use_sim_effort |
If |
... |
Passed on to the rate functions. |
An ArrayTimeBySpecies object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.