MizerSim rate getter that resolves the rate functions onceLike sim_size_rate() but for getters that return one value per species at
each time step (a time-by-species array), such as getRDI() and getRDD().
These use the initial effort, matching their MizerParams counterparts.
sim_species_rate(sim, time_range, target, slot, value_name, units = NULL, ...)An ArrayTimeBySpecies object.
A MizerSim object.
Passed to the sim iteration helper.
Name of the rate to calculate (as in params@rates_funcs).
Name of the element to extract from the mizer_rates_subset()
result (e.g. "e_growth" for the EGrowth rate).
Metadata for the returned array.
Passed on to the rate functions.