| spectra_bin_width | R Documentation |
Matches the weights in the plotting data to the model's full size grid and returns the corresponding bin widths.
spectra_bin_width(w, params)
w |
Numeric vector of weights. |
params |
A MizerParams object. |
A numeric vector of bin widths, one for each entry of w.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.