Learn R Programming

mizer (version 3.0.0)

spectra_bin_width: Look up the size-bin widths for spectra data

Description

Matches the weights in the plotting data to the model's full size grid and returns the corresponding bin widths.

Usage

spectra_bin_width(w, params)

Value

A numeric vector of bin widths, one for each entry of w.

Arguments

w

Numeric vector of weights.

params

A MizerParams object.