Y-axis label for a size-spectrum plot
spectra_y_label(
power,
size_axis = "w",
biomass = power >= 1,
per_log_size = power == 2
)A character string for the y-axis label.
The power of weight that the abundance was multiplied by.
Either "w" (weight) or "l" (length).
Whether the quantity is a biomass density rather than a
number density. Defaults to power >= 1.
Whether the quantity is a density with respect to
logarithmic size. Defaults to power == 2.