| str | R Documentation |
Mizer provides str() methods for MizerParams() and MizerSim() objects,
as well as ArraySpeciesBySize(), ArrayTimeBySpecies() and ArrayTimeBySpeciesBySize()
objects. These methods produce a clean, compact overview of the object's structure
without polluting the console with large amounts of internal data.
## S3 method for class 'ArraySpeciesBySize'
str(object, ...)
## S3 method for class 'ArrayTimeBySpecies'
str(object, ...)
## S3 method for class 'ArrayTimeBySpeciesBySize'
str(object, ...)
## S3 method for class 'MizerSim'
str(object, max.level = NA, ...)
## S3 method for class 'MizerParams'
str(object, max.level = NA, ...)
object |
The object to display the structure of. |
max.level |
Maximum level of nesting to print. Defaults to |
... |
Further arguments. They are passed to the default |
NULL, invisibly.
print(), as.data.frame(), summary(), plot(), MizerParams(), MizerSim(), ArraySpeciesBySize(),
ArrayTimeBySpecies(), ArrayTimeBySpeciesBySize()
str(NS_params)
str(NS_sim)
str(getEncounter(NS_params))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.