If the gears argument contains invalid gears, then these are ignored but a warning is issued.
valid_gears_arg(object, gears = NULL, error_on_empty = FALSE)A vector of gear names in the same order as supplied in gears,
with invalid names removed. If gears is NULL, all gears are returned
in the order stored in the model.
A MizerSim or MizerParams object from which the gears should be selected.
The gears to be selected. Optional. By default all gears are selected. A vector of gear names.
Whether to throw an error if there are zero valid gears. Default FALSE.